@@ -122,9 +122,11 @@ sed --in-place 's/MLPACK_VERSION_MINOR [0-9]*$/MLPACK_VERSION_MINOR '$MINOR'/' \
     src/mlpack/core/util/version.hpp;
 sed --in-place 's/MLPACK_VERSION_PATCH [0-9]*$/MLPACK_VERSION_PATCH '$PATCH'/' \
     src/mlpack/core/util/version.hpp;
+sed --in-place 's/^#define MLPACK_PRERELEASE/\/\/#define MLPACK_PRERELEASE/' \
+    src/mlpack/core/util/version.hpp;
 
 sed --in-place 's/mlpack-[0-9]\.[0-9]\.[0-9]/mlpack-'$MAJOR'.'$MINOR'.'$PATCH'/g' \
-    doc/user/sample_ml_app.md;
+    doc/user/deploy_windows.md;
 sed --in-place 's/mlpack-[0-9]\.[0-9]\.[0-9]/mlpack-'$MAJOR'.'$MINOR'.'$PATCH'/g' \
     doc/examples/sample-ml-app/README.txt;
 sed --in-place 's/mlpack-[0-9]\.[0-9]\.[0-9]/mlpack-'$MAJOR'.'$MINOR'.'$PATCH'/g' \
@@ -157,7 +159,7 @@ rm -rf /tmp/ensmallen;
 git checkout -b release-$MAJOR.$MINOR.$PATCH;
 
 git add src/mlpack/core/util/version.hpp \
-    doc/user/sample_ml_app.md \
+    doc/user/deploy_windows.md \
     doc/examples/sample-ml-app/README.txt \
     doc/examples/sample-ml-app/sample-ml-app/sample-ml-app.vcxproj \
     CMakeLists.txt \
