@@ -26,10 +26,10 @@ std::string DefaultParamImpl(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
     const std::enable_if_t<!util::IsStdVector<T>::value>*,
-    const std::enable_if_t<!data::HasSerialize<T>::value>*,
+    const std::enable_if_t<!HasSerialize<T>::value>*,
     const std::enable_if_t<!std::is_same_v<T, std::string>>*,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>*)
+        std::tuple<mlpack::DatasetInfo, arma::mat>>>*)
 {
   std::ostringstream oss;
   if (std::is_same_v<T, bool>)
@@ -116,7 +116,7 @@ std::string DefaultParamImpl(
     util::ParamData& /* data */,
     const std::enable_if_t<
         arma::is_arma_type<T>::value ||
-        std::is_same_v<T, std::tuple<mlpack::data::DatasetInfo,
+        std::is_same_v<T, std::tuple<mlpack::DatasetInfo,
                                      arma::mat>>>* /* junk */)
 {
   // Get the filename and return it, or return an empty string.
@@ -145,7 +145,7 @@ template<typename T>
 std::string DefaultParamImpl(
     util::ParamData& /* data */,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
-    const std::enable_if_t<data::HasSerialize<T>::value>*)
+    const std::enable_if_t<HasSerialize<T>::value>*)
 {
   return "NA";
 }
