@@ -27,9 +27,9 @@ std::string GetPrintableParam(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
     const std::enable_if_t<!util::IsStdVector<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<DatasetInfo, arma::mat>>>* = 0)
 {
   std::ostringstream oss;
   oss << std::any_cast<T>(data.value);
@@ -75,7 +75,7 @@ template<typename T>
 std::string GetPrintableParam(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<data::HasSerialize<T>::value>* = 0)
+    const std::enable_if_t<HasSerialize<T>::value>* = 0)
 {
   std::ostringstream oss;
   oss << data.cppType << " model at " << std::any_cast<T*>(data.value);
@@ -89,7 +89,7 @@ template<typename T>
 std::string GetPrintableParam(
     util::ParamData& data,
     const std::enable_if_t<std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<DatasetInfo, arma::mat>>>* = 0)
 {
   // Get the matrix.
   const T& tuple = std::any_cast<T>(data.value);
