@@ -25,10 +25,10 @@ template<typename T>
 inline std::string GetType(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<DatasetInfo, arma::mat>>>* = 0)
 {
   return "unknown";
 }
@@ -37,10 +37,10 @@ template<>
 inline std::string GetType<int>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<int>::value>*,
-    const std::enable_if_t<!data::HasSerialize<int>::value>*,
+    const std::enable_if_t<!HasSerialize<int>::value>*,
     const std::enable_if_t<!arma::is_arma_type<int>::value>*,
     const std::enable_if_t<!std::is_same_v<int,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "Int";
 }
@@ -49,10 +49,10 @@ template<>
 inline std::string GetType<float>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<float>::value>*,
-    const std::enable_if_t<!data::HasSerialize<float>::value>*,
+    const std::enable_if_t<!HasSerialize<float>::value>*,
     const std::enable_if_t<!arma::is_arma_type<float>::value>*,
     const std::enable_if_t<!std::is_same_v<float,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "Float";
 }
@@ -61,10 +61,10 @@ template<>
 inline std::string GetType<double>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<double>::value>*,
-    const std::enable_if_t<!data::HasSerialize<double>::value>*,
+    const std::enable_if_t<!HasSerialize<double>::value>*,
     const std::enable_if_t<!arma::is_arma_type<double>::value>*,
     const std::enable_if_t<!std::is_same_v<double,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "Double";
 }
@@ -73,10 +73,10 @@ template<>
 inline std::string GetType<std::string>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<std::string>::value>*,
-    const std::enable_if_t<!data::HasSerialize<std::string>::value>*,
+    const std::enable_if_t<!HasSerialize<std::string>::value>*,
     const std::enable_if_t<!arma::is_arma_type<std::string>::value>*,
     const std::enable_if_t<!std::is_same_v<std::string,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "String";
 }
@@ -85,10 +85,10 @@ template<>
 inline std::string GetType<bool>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<bool>::value>*,
-    const std::enable_if_t<!data::HasSerialize<bool>::value>*,
+    const std::enable_if_t<!HasSerialize<bool>::value>*,
     const std::enable_if_t<!arma::is_arma_type<bool>::value>*,
     const std::enable_if_t<!std::is_same_v<bool,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "Bool";
 }
@@ -98,7 +98,7 @@ inline std::string GetType(
     util::ParamData& d,
     const std::enable_if_t<util::IsStdVector<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<DatasetInfo, arma::mat>>>* = 0)
 {
   return "Vec" + GetType<typename T::value_type>(d);
 }
@@ -108,7 +108,7 @@ inline std::string GetType(
     util::ParamData& /* d */,
     const std::enable_if_t<arma::is_arma_type<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<DatasetInfo, arma::mat>>>* = 0)
 {
   std::string type = "";
   if (std::is_same_v<typename T::elem_type, double>)
@@ -137,7 +137,7 @@ template<typename T>
 inline std::string GetType(
     util::ParamData& /* d */,
     const std::enable_if_t<std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<DatasetInfo, arma::mat>>>* = 0)
 {
   return "MatWithInfo";
 }
@@ -146,7 +146,7 @@ template<typename T>
 inline std::string GetType(
     util::ParamData& d,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<data::HasSerialize<T>::value>* = 0)
+    const std::enable_if_t<HasSerialize<T>::value>* = 0)
 {
   return d.cppType;
 }
