@@ -28,10 +28,10 @@ std::string DefaultParamImpl(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
     const std::enable_if_t<!util::IsStdVector<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T, std::string>>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>* = 0);
+        std::tuple<mlpack::DatasetInfo, arma::mat>>>* = 0);
 
 /**
  * Return the default value of a vector option.
@@ -59,7 +59,7 @@ std::string DefaultParamImpl(
     util::ParamData& data,
     const std::enable_if_t<
         arma::is_arma_type<T>::value ||
-        std::is_same_v<T, std::tuple<mlpack::data::DatasetInfo,
+        std::is_same_v<T, std::tuple<mlpack::DatasetInfo,
                                      arma::mat>>>* /* junk */ = 0);
 
 /**
@@ -70,7 +70,7 @@ template<typename T>
 std::string DefaultParamImpl(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<data::HasSerialize<T>::value>* = 0);
+    const std::enable_if_t<HasSerialize<T>::value>* = 0);
 
 /**
  * Return the default value of an option.  This is the function that will be
