@@ -29,9 +29,9 @@ std::string GetPrintableParam(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
     const std::enable_if_t<!util::IsStdVector<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0);
+        std::tuple<DatasetInfo, arma::mat>>>* = 0);
 
 /**
  * Print a vector option, with spaces between it.
@@ -48,7 +48,7 @@ template<typename T>
 std::string GetPrintableParam(
     util::ParamData& data,
     const std::enable_if_t<arma::is_arma_type<T>::value || std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0);
+        std::tuple<DatasetInfo, arma::mat>>>* = 0);
 
 /**
  * Print a model option (this just prints the filename).
@@ -57,7 +57,7 @@ template<typename T>
 std::string GetPrintableParam(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<data::HasSerialize<T>::value>* = 0);
+    const std::enable_if_t<HasSerialize<T>::value>* = 0);
 
 /**
  * Print an option into a std::string.  This should print a short, one-line
