@@ -25,9 +25,9 @@ std::string GetPrintableParam(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
     const std::enable_if_t<!util::IsStdVector<T>::value>*,
-    const std::enable_if_t<!data::HasSerialize<T>::value>*,
+    const std::enable_if_t<!HasSerialize<T>::value>*,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   std::ostringstream oss;
   oss << std::any_cast<T>(data.value);
@@ -64,7 +64,7 @@ template<typename T>
 std::string GetMatrixSize(
     T& matrixAndInfo,
     const std::enable_if_t<std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<DatasetInfo, arma::mat>>>* = 0)
 {
   return GetMatrixSize(std::get<1>(matrixAndInfo));
 }
@@ -74,7 +74,7 @@ template<typename T>
 std::string GetPrintableParam(
     util::ParamData& data,
     const std::enable_if_t<arma::is_arma_type<T>::value || std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* /* junk */)
+        std::tuple<DatasetInfo, arma::mat>>>* /* junk */)
 {
   // Extract the string from the tuple that's being held.
   using TupleType = std::tuple<T, typename ParameterType<T>::type>;
@@ -102,7 +102,7 @@ template<typename T>
 std::string GetPrintableParam(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
-    const std::enable_if_t<data::HasSerialize<T>::value>*)
+    const std::enable_if_t<HasSerialize<T>::value>*)
 {
   // Extract the string from the tuple that's being held.
   using TupleType = std::tuple<T*, typename ParameterType<T>::type>;
