@@ -29,9 +29,9 @@ std::string GetPrintableParamValue(
     util::ParamData& /* data */,
     const std::string& input,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
-    const std::enable_if_t<!data::HasSerialize<T>::value>*,
+    const std::enable_if_t<!HasSerialize<T>::value>*,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return input;
 }
@@ -58,7 +58,7 @@ std::string GetPrintableParamValue(
     util::ParamData& /* data */,
     const std::string& input,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
-    const std::enable_if_t<data::HasSerialize<T>::value>*)
+    const std::enable_if_t<HasSerialize<T>::value>*)
 {
   return input + ".bin";
 }
@@ -72,7 +72,7 @@ std::string GetPrintableParamValue(
     util::ParamData& /* data */,
     const std::string& input,
     const std::enable_if_t<std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return input + ".arff";
 }
