@@ -32,9 +32,9 @@ void InPlaceCopyInternal(
     util::ParamData& /* d */,
     util::ParamData& /* input */,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<mlpack::DatasetInfo, arma::mat>>>* = 0)
 {
   // Nothing to do.
 }
@@ -52,8 +52,7 @@ void InPlaceCopyInternal(
     util::ParamData& input,
     const std::enable_if_t<
         arma::is_arma_type<T>::value ||
-        std::is_same_v<T, std::tuple<mlpack::data::DatasetInfo, arma::mat>>>*
-            = 0)
+        std::is_same_v<T, std::tuple<mlpack::DatasetInfo, arma::mat>>>* = 0)
 {
   // Make the output filename the same as the input filename.
   using TupleType = std::tuple<T, typename ParameterType<T>::type>;
@@ -75,7 +74,7 @@ template<typename T>
 void InPlaceCopyInternal(
     util::ParamData& d,
     util::ParamData& input,
-    const std::enable_if_t<data::HasSerialize<T>::value>* = 0)
+    const std::enable_if_t<HasSerialize<T>::value>* = 0)
 {
   // Make the output filename the same as the input filename.
   using TupleType = std::tuple<T*, typename ParameterType<T>::type>;
