@@ -28,9 +28,9 @@ template<typename T>
 std::string MapParameterName(
     const std::string& identifier,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<mlpack::DatasetInfo, arma::mat>>>* = 0)
 {
   return identifier;
 }
@@ -45,8 +45,8 @@ std::string MapParameterName(
     const std::string& identifier,
     const std::enable_if_t<
         arma::is_arma_type<T>::value ||
-        std::is_same_v<T, std::tuple<mlpack::data::DatasetInfo, arma::mat>> ||
-        data::HasSerialize<T>::value>* /* junk */ = 0)
+        std::is_same_v<T, std::tuple<mlpack::DatasetInfo, arma::mat>> ||
+        HasSerialize<T>::value>* /* junk */ = 0)
 {
   return identifier + "_file";
 }
