@@ -28,9 +28,9 @@ void OutputParamImpl(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
     const std::enable_if_t<!util::IsStdVector<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0);
+        std::tuple<DatasetInfo, arma::mat>>>* = 0);
 
 /**
  * Output a vector option (print to stdout).
@@ -55,7 +55,7 @@ template<typename T>
 void OutputParamImpl(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<data::HasSerialize<T>::value>* = 0);
+    const std::enable_if_t<HasSerialize<T>::value>* = 0);
 
 /**
  * Output a mapped dataset.
@@ -64,7 +64,7 @@ template<typename T>
 void OutputParamImpl(
     util::ParamData& data,
     const std::enable_if_t<std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0);
+        std::tuple<DatasetInfo, arma::mat>>>* = 0);
 
 /**
  * Output an option.  This is the function that will be called by the IO
