@@ -28,9 +28,9 @@ void SetParam(
     util::ParamData& d,
     const std::any& value,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<mlpack::data::DatasetInfo, arma::mat>>>* = 0,
+        std::tuple<mlpack::DatasetInfo, arma::mat>>>* = 0,
     const std::enable_if_t<!std::is_same_v<T, bool>>* = 0)
 {
   // No mapping is needed.
@@ -59,7 +59,7 @@ void SetParam(
     util::ParamData& d,
     const std::any& value,
     const std::enable_if_t<arma::is_arma_type<T>::value || std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0)
+        std::tuple<DatasetInfo, arma::mat>>>* = 0)
 {
   // We're setting the string filename.
   using TupleType = std::tuple<T, typename ParameterType<T>::type>;
@@ -76,7 +76,7 @@ void SetParam(
     util::ParamData& d,
     const std::any& value,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<data::HasSerialize<T>::value>* = 0)
+    const std::enable_if_t<HasSerialize<T>::value>* = 0)
 {
   // We're setting the string filename.
   using TupleType = std::tuple<T*, typename ParameterType<T>::type>;
