@@ -24,10 +24,10 @@ template<typename T>
 inline std::string GetPrintableType(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<T>::value>*,
-    const std::enable_if_t<!data::HasSerialize<T>::value>*,
+    const std::enable_if_t<!HasSerialize<T>::value>*,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "unknown";
 }
@@ -36,10 +36,10 @@ template<>
 inline std::string GetPrintableType<int>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<int>::value>*,
-    const std::enable_if_t<!data::HasSerialize<int>::value>*,
+    const std::enable_if_t<!HasSerialize<int>::value>*,
     const std::enable_if_t<!arma::is_arma_type<int>::value>*,
     const std::enable_if_t<!std::is_same_v<int,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "int";
 }
@@ -48,10 +48,10 @@ template<>
 inline std::string GetPrintableType<double>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<double>::value>*,
-    const std::enable_if_t<!data::HasSerialize<double>::value>*,
+    const std::enable_if_t<!HasSerialize<double>::value>*,
     const std::enable_if_t<!arma::is_arma_type<double>::value>*,
     const std::enable_if_t<!std::is_same_v<double,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "float64";
 }
@@ -60,10 +60,10 @@ template<>
 inline std::string GetPrintableType<std::string>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<std::string>::value>*,
-    const std::enable_if_t<!data::HasSerialize<std::string>::value>*,
+    const std::enable_if_t<!HasSerialize<std::string>::value>*,
     const std::enable_if_t<!arma::is_arma_type<std::string>::value>*,
     const std::enable_if_t<!std::is_same_v<std::string,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "string";
 }
@@ -72,10 +72,10 @@ template<>
 inline std::string GetPrintableType<bool>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<bool>::value>*,
-    const std::enable_if_t<!data::HasSerialize<bool>::value>*,
+    const std::enable_if_t<!HasSerialize<bool>::value>*,
     const std::enable_if_t<!arma::is_arma_type<bool>::value>*,
     const std::enable_if_t<!std::is_same_v<bool,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "bool";
 }
@@ -85,7 +85,7 @@ inline std::string GetPrintableType(
     util::ParamData& d,
     const std::enable_if_t<util::IsStdVector<T>::value>*,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "array of " + GetPrintableType<typename T::value_type>(d) + "s";
 }
@@ -95,7 +95,7 @@ inline std::string GetPrintableType(
     util::ParamData& /* d */,
     const std::enable_if_t<arma::is_arma_type<T>::value>*,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   std::string type = "*mat.Dense";
   if (T::is_row || T::is_col)
@@ -108,7 +108,7 @@ template<typename T>
 inline std::string GetPrintableType(
     util::ParamData& /* d */,
     const std::enable_if_t<std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "matrixWithInfo";
 }
@@ -117,9 +117,9 @@ template<typename T>
 inline std::string GetPrintableType(
     util::ParamData& d,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
-    const std::enable_if_t<data::HasSerialize<T>::value>*,
+    const std::enable_if_t<HasSerialize<T>::value>*,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   std::string goStrippedType, strippedType, printedType, defaultsType;
   StripType(d.cppType, goStrippedType, strippedType, printedType, defaultsType);
