@@ -28,9 +28,9 @@ std::string GetPrintableType(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
     const std::enable_if_t<!util::IsStdVector<T>::value>*,
-    const std::enable_if_t<!data::HasSerialize<T>::value>*,
+    const std::enable_if_t<!HasSerialize<T>::value>*,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   if (std::is_same_v<T, bool>)
     return "Bool";
@@ -91,7 +91,7 @@ template<typename T>
 std::string GetPrintableType(
     util::ParamData& /* data */,
     const std::enable_if_t<std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "Tuple{Array{Bool, 1}, Array{Float64, 2}}";
 }
@@ -103,7 +103,7 @@ template<typename T>
 std::string GetPrintableType(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
-    const std::enable_if_t<data::HasSerialize<T>::value>*)
+    const std::enable_if_t<HasSerialize<T>::value>*)
 {
   std::string type = util::StripType(data.cppType);
   if (type == "mlpackModel")
