@@ -27,9 +27,9 @@ template<typename T>
 std::string GetPrintableParamName(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0);
+        std::tuple<DatasetInfo, arma::mat>>>* = 0);
 
 /**
  * Get the parameter name for a matrix type (where the user has to pass the file
@@ -48,7 +48,7 @@ template<typename T>
 std::string GetPrintableParamName(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<data::HasSerialize<T>::value>* = 0);
+    const std::enable_if_t<HasSerialize<T>::value>* = 0);
 
 /**
  * Get the parameter name for a mapped matrix type (where the user has to pass
@@ -58,7 +58,7 @@ template<typename T>
 std::string GetPrintableParamName(
     util::ParamData& data,
     const std::enable_if_t<std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>* = 0);
+        std::tuple<DatasetInfo, arma::mat>>>* = 0);
 
 /**
  * Get the parameter's name as seen by the user.
