@@ -27,9 +27,9 @@ template<typename T>
 std::string GetPrintableParamName(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
-    const std::enable_if_t<!data::HasSerialize<T>::value>*,
+    const std::enable_if_t<!HasSerialize<T>::value>*,
     const std::enable_if_t<!std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "--" + data.name;
 }
@@ -54,7 +54,7 @@ template<typename T>
 std::string GetPrintableParamName(
     util::ParamData& data,
     const std::enable_if_t<!arma::is_arma_type<T>::value>*,
-    const std::enable_if_t<data::HasSerialize<T>::value>*)
+    const std::enable_if_t<HasSerialize<T>::value>*)
 {
   return "--" + data.name + "_file";
 }
@@ -67,7 +67,7 @@ template<typename T>
 std::string GetPrintableParamName(
     util::ParamData& data,
     const std::enable_if_t<std::is_same_v<T,
-        std::tuple<data::DatasetInfo, arma::mat>>>*)
+        std::tuple<DatasetInfo, arma::mat>>>*)
 {
   return "--" + data.name + "_file";
 }
