@@ -24,7 +24,7 @@ template<typename T>
 inline std::string GetCythonType(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<T>::value>* = 0,
-    const std::enable_if_t<!data::HasSerialize<T>::value>* = 0,
+    const std::enable_if_t<!HasSerialize<T>::value>* = 0,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0)
 {
   return "unknown";
@@ -34,7 +34,7 @@ template<>
 inline std::string GetCythonType<int>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<int>::value>*,
-    const std::enable_if_t<!data::HasSerialize<int>::value>*,
+    const std::enable_if_t<!HasSerialize<int>::value>*,
     const std::enable_if_t<!arma::is_arma_type<int>::value>*)
 {
   return "int";
@@ -44,7 +44,7 @@ template<>
 inline std::string GetCythonType<double>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<double>::value>*,
-    const std::enable_if_t<!data::HasSerialize<double>::value>*,
+    const std::enable_if_t<!HasSerialize<double>::value>*,
     const std::enable_if_t<!arma::is_arma_type<double>::value>*)
 {
   return "double";
@@ -54,7 +54,7 @@ template<>
 inline std::string GetCythonType<std::string>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<std::string>::value>*,
-    const std::enable_if_t<!data::HasSerialize<std::string>::value>*,
+    const std::enable_if_t<!HasSerialize<std::string>::value>*,
     const std::enable_if_t<!arma::is_arma_type<std::string>::value>*)
 {
   return "string";
@@ -64,7 +64,7 @@ template<>
 inline std::string GetCythonType<size_t>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<size_t>::value>*,
-    const std::enable_if_t<!data::HasSerialize<size_t>::value>*,
+    const std::enable_if_t<!HasSerialize<size_t>::value>*,
     const std::enable_if_t<!arma::is_arma_type<size_t>::value>*)
 {
   return "size_t";
@@ -74,7 +74,7 @@ template<>
 inline std::string GetCythonType<bool>(
     util::ParamData& /* d */,
     const std::enable_if_t<!util::IsStdVector<bool>::value>*,
-    const std::enable_if_t<!data::HasSerialize<bool>::value>*,
+    const std::enable_if_t<!HasSerialize<bool>::value>*,
     const std::enable_if_t<!arma::is_arma_type<bool>::value>*)
 {
   return "cbool";
@@ -106,7 +106,7 @@ template<typename T>
 inline std::string GetCythonType(
     util::ParamData& d,
     const std::enable_if_t<!arma::is_arma_type<T>::value>* = 0,
-    const std::enable_if_t<data::HasSerialize<T>::value>* = 0)
+    const std::enable_if_t<HasSerialize<T>::value>* = 0)
 {
   return d.cppType + "*";
 }
