@@ -2,7 +2,7 @@
  * @file bindings/python/mlpack/serialization.hpp
  * @author Ryan Curtin
  *
- * Simple utilities for boost::serialization.
+ * Simple utilities for cereal.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
@@ -23,9 +23,9 @@ std::string SerializeOut(T* t, const std::string& name)
 {
   std::ostringstream oss;
   {
-    boost::archive::binary_oarchive b(oss);
+    cereal::BinaryOutputArchive b(oss);
 
-    b << boost::serialization::make_nvp(name.c_str(), *t);
+    b(cereal::make_nvp(name.c_str(), *t));
   }
   return oss.str();
 }
@@ -34,9 +34,28 @@ template<typename T>
 void SerializeIn(T* t, const std::string& str, const std::string& name)
 {
   std::istringstream iss(str);
-  boost::archive::binary_iarchive b(iss);
+  cereal::BinaryInputArchive b(iss);
+  b(cereal::make_nvp(name.c_str(), *t));
+}
 
-  b >> boost::serialization::make_nvp(name.c_str(), *t);
+template<typename T>
+std::string SerializeOutJSON(T* t, const std::string& name)
+{
+  std::ostringstream oss;
+  {
+    cereal::JSONOutputArchive b(oss);
+
+    b(cereal::make_nvp(name.c_str(), *t));
+  }
+  return oss.str();
+}
+
+template<typename T>
+void SerializeInJSON(T* t, const std::string& str, const std::string& name)
+{
+  std::istringstream iss(str);
+  cereal::JSONInputArchive b(iss);
+  b(cereal::make_nvp(name.c_str(), *t));
 }
 
 } // namespace python
