@@ -15,7 +15,6 @@
 #include <mlpack/core/cv/meta_info_extractor.hpp>
 
 namespace mlpack {
-namespace cv {
 
 /**
  * An auxiliary class for cross-validation. It serves to handle basic non-data
@@ -58,12 +57,12 @@ class CVBase
 
   /**
    * Assert that MLAlgorithm takes the numClasses parameter and a
-   * data::DatasetInfo parameter and store them.
+   * DatasetInfo parameter and store them.
    *
    * @param datasetInfo Type information for each dimension of the dataset.
    * @param numClasses Number of classes in the dataset.
    */
-  CVBase(const data::DatasetInfo& datasetInfo,
+  CVBase(const DatasetInfo& datasetInfo,
          const size_t numClasses);
 
   /**
@@ -102,9 +101,9 @@ class CVBase
   static_assert(MIE::IsSupported,
       "The given MLAlgorithm is not supported by MetaInfoExtractor");
 
-  //! A variable for storing a data::DatasetInfo parameter if it is passed.
-  const data::DatasetInfo datasetInfo;
-  //! An indicator whether a data::DatasetInfo parameter has been passed.
+  //! A variable for storing a DatasetInfo parameter if it is passed.
+  const DatasetInfo datasetInfo;
+  //! An indicator whether a DatasetInfo parameter has been passed.
   const bool isDatasetInfoPassed;
   //! A variable for storing the numClasses parameter if it is passed.
   size_t numClasses;
@@ -127,7 +126,7 @@ class CVBase
    */
   template<typename... MLAlgorithmArgs,
            bool Enabled = !MIE::TakesNumClasses,
-           typename = typename std::enable_if<Enabled>::type>
+           typename = std::enable_if_t<Enabled>>
   MLAlgorithm TrainModel(const MatType& xs,
                          const PredictionsType& ys,
                          const MLAlgorithmArgs&... args);
@@ -138,7 +137,7 @@ class CVBase
    */
   template<typename... MLAlgorithmArgs,
            bool Enabled = MIE::TakesNumClasses & !MIE::TakesDatasetInfo,
-           typename = typename std::enable_if<Enabled>::type,
+           typename = std::enable_if_t<Enabled>,
            typename = void>
   MLAlgorithm TrainModel(const MatType& xs,
                          const PredictionsType& ys,
@@ -146,11 +145,11 @@ class CVBase
 
   /**
    * Construct a trained MLAlgorithm model if MLAlgorithm takes the
-   * numClasses parameter and a data::DatasetInfo parameter.
+   * numClasses parameter and a DatasetInfo parameter.
    */
   template<typename... MLAlgorithmArgs,
            bool Enabled = MIE::TakesNumClasses & MIE::TakesDatasetInfo,
-           typename = typename std::enable_if<Enabled>::type,
+           typename = std::enable_if_t<Enabled>,
            typename = void,
            typename = void>
   MLAlgorithm TrainModel(const MatType& xs,
@@ -163,7 +162,7 @@ class CVBase
    */
   template<typename... MLAlgorithmArgs,
            bool Enabled = !MIE::TakesNumClasses,
-           typename = typename std::enable_if<Enabled>::type>
+           typename = std::enable_if_t<Enabled>>
   MLAlgorithm TrainModel(const MatType& xs,
                          const PredictionsType& ys,
                          const WeightsType& weights,
@@ -175,7 +174,7 @@ class CVBase
    */
   template<typename... MLAlgorithmArgs,
            bool Enabled = MIE::TakesNumClasses & !MIE::TakesDatasetInfo,
-           typename = typename std::enable_if<Enabled>::type,
+           typename = std::enable_if_t<Enabled>,
            typename = void>
   MLAlgorithm TrainModel(const MatType& xs,
                          const PredictionsType& ys,
@@ -184,11 +183,11 @@ class CVBase
 
   /**
    * Construct a trained MLAlgorithm model if MLAlgorithm takes the
-   * numClasses parameter and a data::DatasetInfo parameter.
+   * numClasses parameter and a DatasetInfo parameter.
    */
   template<typename... MLAlgorithmArgs,
            bool Enabled = MIE::TakesNumClasses & MIE::TakesDatasetInfo,
-           typename = typename std::enable_if<Enabled>::type,
+           typename = std::enable_if_t<Enabled>,
            typename = void,
            typename = void>
   MLAlgorithm TrainModel(const MatType& xs,
@@ -197,37 +196,34 @@ class CVBase
                          const MLAlgorithmArgs&... args);
 
   /**
-   * When MLAlgorithm supports a data::DatasetInfo parameter, training should be
+   * When MLAlgorithm supports a DatasetInfo parameter, training should be
    * treated separately - there are models that can be constructed with and
    * without a data:DatasetInfo parameter and models that can be constructed
-   * only with a data::DatasetInfo parameter.
+   * only with a DatasetInfo parameter.
    *
    * Construct a trained MLAlgorithm model when it can be constructed without a
-   * data::DatasetInfo parameter.
+   * DatasetInfo parameter.
    */
   template<bool ConstructableWithoutDatasetInfo,
            typename... MLAlgorithmArgs,
-           typename =
-               typename std::enable_if<ConstructableWithoutDatasetInfo>::type>
+           typename = std::enable_if_t<ConstructableWithoutDatasetInfo>>
   MLAlgorithm TrainModel(const MatType& xs,
                          const PredictionsType& ys,
                          const MLAlgorithmArgs&... args);
 
   /**
    * Construct a trained MLAlgorithm model when it can't be constructed without
-   * a data::DatasetInfo parameter.
+   * a DatasetInfo parameter.
    */
   template<bool ConstructableWithoutDatasetInfo,
            typename... MLAlgorithmArgs,
-           typename =
-               typename std::enable_if<!ConstructableWithoutDatasetInfo>::type,
+           typename = std::enable_if_t<!ConstructableWithoutDatasetInfo>,
            typename = void>
   MLAlgorithm TrainModel(const MatType& xs,
                          const PredictionsType& ys,
                          const MLAlgorithmArgs&... args);
 };
 
-} // namespace cv
 } // namespace mlpack
 
 // Include implementation
