@@ -13,7 +13,6 @@
 #define MLPACK_CORE_DATA_DATA_HPP
 
 #include "extension.hpp"
-#include "format.hpp"
 #include "has_serialize.hpp"
 
 #include "load.hpp"
@@ -31,8 +30,11 @@
 #include "dataset_mapper.hpp"
 #include "data_options.hpp"
 #include "detect_file_type.hpp"
-#include "image_info.hpp"
+#include "image_layout.hpp"
+#include "image_options.hpp"
 #include "image_resize_crop.hpp"
+#include "image_letterbox.hpp"
+#include "image_bounding_box.hpp"
 #include "imputer.hpp"
 #include "is_naninf.hpp"
 #include "matrix_options.hpp"
@@ -41,7 +43,7 @@
 #include "split_data.hpp"
 #include "string_algorithms.hpp"
 #include "text_options.hpp"
-#include "types.hpp"
-#include "utilities.hpp"
+
+#include "combine_options.hpp"
 
 #endif
