@@ -1,9 +1,9 @@
 /**
- * @file extension.hpp
+ * @file core/data/extension.hpp
  * @author Ryan Curtin
  *
- * Given a filename, extract its extension.  This is used by data::Load() and
- * data::Save().
+ * Given a filename, extract its extension.  This is used by Load() and
+ * Save().
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
@@ -16,7 +16,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace data {
 
 inline std::string Extension(const std::string& filename)
 {
@@ -32,7 +31,6 @@ inline std::string Extension(const std::string& filename)
   return extension;
 }
 
-} // namespace data
 } // namespace mlpack
 
 #endif
