@@ -15,7 +15,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace data {
 
 /**
  * A simple Mean Normalization class
@@ -54,9 +53,9 @@ class MeanNormalization
   template<typename MatType>
   void Fit(const MatType& input)
   {
-    itemMean = arma::mean(input, 1);
-    itemMin = arma::min(input, 1);
-    itemMax = arma::max(input, 1);
+    itemMean = mean(input, 1);
+    itemMin = min(input, 1);
+    itemMax = max(input, 1);
     scale = itemMax - itemMin;
     // Handling zeros in scale vector.
     scale.for_each([](arma::vec::elem_type& val) { val =
@@ -123,7 +122,6 @@ class MeanNormalization
   arma::vec scale;
 }; // class MeanNormalization
 
-} // namespace data
 } // namespace mlpack
 
 #endif
