@@ -1,5 +1,5 @@
 /**
- * @file zca_whitening.hpp
+ * @file core/data/scaler_methods/zca_whitening.hpp
  * @author Jeffin Sam
  *
  * Whitening scaling to scale features, Using ZCA Whitening.
@@ -13,11 +13,9 @@
 #define MLPACK_CORE_DATA_ZCA_WHITENING_SCALE_HPP
 
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/math/lin_alg.hpp>
 #include <mlpack/core/data/scaler_methods/pca_whitening.hpp>
 
 namespace mlpack {
-namespace data {
 
 /**
  * A simple ZCAWhitening class.
@@ -87,7 +85,7 @@ class ZCAWhitening
   template<typename MatType>
   void InverseTransform(const MatType& input, MatType& output)
   {
-    output = inv(pca.EigenVectors()) * arma::diagmat(arma::sqrt(
+    output = inv(pca.EigenVectors()) * arma::diagmat(sqrt(
         pca.EigenValues())) * inv(pca.EigenVectors().t()) * input;
     output = (output.each_col() + pca.ItemMean());
   }
@@ -102,9 +100,9 @@ class ZCAWhitening
   double Epsilon() const { return pca.Epsilon(); }
 
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(pca);
+    ar(CEREAL_NVP(pca));
   }
 
  private:
@@ -112,7 +110,6 @@ class ZCAWhitening
   PCAWhitening pca;
 }; // class ZCAWhitening
 
-} // namespace data
 } // namespace mlpack
 
 #endif
