@@ -14,13 +14,13 @@
 #define MLPACK_CORE_DATA_STRING_ENCODING_DICTIONARY_HPP
 
 #include <mlpack/prereqs.hpp>
-#include <mlpack/core/boost_backport/boost_backport_string_view.hpp>
-#include <unordered_map>
-#include <deque>
+
 #include <array>
+#include <deque>
+#include <functional>
+#include <unordered_map>
 
 namespace mlpack {
-namespace data {
 
 /**
  * This class provides a dictionary interface for the purpose of string
@@ -94,9 +94,9 @@ class StringEncodingDictionary
    * Serialize the class to the given archive.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(mapping);
+    ar(CEREAL_NVP(mapping));
   }
 
  private:
@@ -105,20 +105,20 @@ class StringEncodingDictionary
 };
 
 /*
- * Specialization of the StringEncodingDictionary class for boost::string_view.
+ * Specialization of the StringEncodingDictionary class for std::string_view.
  */
 template<>
-class StringEncodingDictionary<boost::string_view>
+class StringEncodingDictionary<std::string_view>
 {
  public:
   //! A convenient alias for the internal type of the map.
   using MapType = std::unordered_map<
-      boost::string_view,
+      std::string_view,
       size_t,
-      boost::hash<boost::string_view>>;
+      std::hash<std::string_view>>;
 
   //! The type of the token that the dictionary stores.
-  using TokenType = boost::string_view;
+  using TokenType = std::string_view;
 
   //! Construct the default class.
   StringEncodingDictionary() = default;
@@ -155,7 +155,7 @@ class StringEncodingDictionary<boost::string_view>
    *
    * @param token The given token.
    */
-  bool HasToken(const boost::string_view token) const
+  bool HasToken(const std::string_view token) const
   {
     return mapping.find(token) != mapping.end();
   }
@@ -167,7 +167,7 @@ class StringEncodingDictionary<boost::string_view>
    *
    * @param token The given token.
    */
-  size_t AddToken(const boost::string_view token)
+  size_t AddToken(const std::string_view token)
   {
     tokens.emplace_back(token);
 
@@ -184,7 +184,7 @@ class StringEncodingDictionary<boost::string_view>
    *
    * @param token The given token.
    */
-  size_t Value(const boost::string_view token) const
+  size_t Value(const std::string_view token) const
   {
     return mapping.at(token);
   }
@@ -213,33 +213,33 @@ class StringEncodingDictionary<boost::string_view>
    * Serialize the class to the given archive.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
     size_t numTokens = tokens.size();
 
-    ar & BOOST_SERIALIZATION_NVP(numTokens);
+    ar(CEREAL_NVP(numTokens));
 
-    if (Archive::is_loading::value)
+    if (cereal::is_loading<Archive>())
     {
       tokens.resize(numTokens);
 
       for (std::string& token : tokens)
       {
-        ar & BOOST_SERIALIZATION_NVP(token);
+        ar(CEREAL_NVP(token));
 
         size_t tokenValue = 0;
-        ar & BOOST_SERIALIZATION_NVP(tokenValue);
+        ar(CEREAL_NVP(tokenValue));
         mapping[token] = tokenValue;
       }
     }
-    if (Archive::is_saving::value)
+    if (cereal::is_saving<Archive>())
     {
       for (std::string& token : tokens)
       {
-        ar & BOOST_SERIALIZATION_NVP(token);
+        ar(CEREAL_NVP(token));
 
         size_t tokenValue = mapping.at(token);
-        ar & BOOST_SERIALIZATION_NVP(tokenValue);
+        ar(CEREAL_NVP(tokenValue));
       }
     }
   }
@@ -328,10 +328,10 @@ class StringEncodingDictionary<int>
    * Serialize the class to the given archive.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(mapping);
-    ar & BOOST_SERIALIZATION_NVP(size);
+    ar(CEREAL_NVP(mapping));
+    ar(CEREAL_NVP(size));
   }
 
  private:
@@ -342,7 +342,6 @@ class StringEncodingDictionary<int>
   size_t size;
 };
 
-} // namespace data
 } // namespace mlpack
 
 #endif
