@@ -76,8 +76,8 @@ class CellBound
  public:
   //! Depending on the precision of the tree element type, we may need to use
   //! uint32_t or uint64_t.
-  using AddressElemType = std::conditional_t<sizeof(ElemType) * CHAR_BIT <= 32,
-                                             uint32_t, uint64_t>;
+  using AddressElemType = std::conditional_t<
+      (sizeof(ElemType) * CHAR_BIT <= 32), uint32_t, uint64_t>;
 
   /**
    * Empty constructor; creates a bound of dimensionality 0.
@@ -143,10 +143,10 @@ class CellBound
   ElemType& MinWidth() { return minWidth; }
 
   //! Get the distance metric associated with this bound.
-  [[deprecated("Will be removed in 5.0.0; use Distance()")]]
+  [[deprecated("Will be removed in mlpack 5.0.0; use Distance()")]]
   const DistanceType& Metric() const { return distance; }
   //! Modify the distance metric associated with this bound.
-  [[deprecated("Will be removed in 5.0.0; use Distance()")]]
+  [[deprecated("Will be removed in mlpack 5.0.0; use Distance()")]]
   DistanceType& Metric() { return distance; }
 
   //! Get the distance metric associated with this bound.
