@@ -27,13 +27,13 @@ bool MeanSpaceSplit<DistanceType, MatType>::SplitSpace(
     HyperplaneType& hyp)
 {
   typename HyperplaneType::ProjVectorType projVector;
-  double midValue;
+  typename MatType::elem_type midValue;
 
   if (!SpaceSplit<DistanceType, MatType>::GetProjVector(bound, data, points,
       projVector, midValue))
     return false;
 
-  double splitVal = 0.0;
+  typename MatType::elem_type splitVal = 0.0;
   for (size_t i = 0; i < points.n_elem; ++i)
     splitVal += projVector.Project(data.col(points[i]));
   splitVal /= points.n_elem;
