@@ -9,7 +9,7 @@
  *
  * @code
  * @inproceedings{GlorotAISTATS2010,
- *   title={title={Understanding the difficulty of training deep feedforward
+ *   title={Understanding the difficulty of training deep feedforward
  *   neural networks},
  *   author={Glorot, Xavier and Bengio, Yoshua},
  *   booktitle={Proceedings of AISTATS 2010},
@@ -34,13 +34,7 @@ namespace mlpack {
  *
  * @f{eqnarray*}{
  * f(x) &=& \frac{x}{1 + |x|} \\
- * f'(x) &=& (1 - |f(x)|)^2 \\
- * f(x) &=& \left\{
- *   \begin{array}{lr}
- *     -\frac{x}{1 - x} & : x \le 0 \\
- *     \frac{x}{1 + x} & : x > 0
- *   \end{array}
- * \right.
+ * f'(x) &=& (1 + |f(x)|)^2 \\
  * @f}
  */
 class SoftsignFunction
@@ -52,11 +46,10 @@ class SoftsignFunction
    * @param x Input data.
    * @return f(x).
    */
-  static double Fn(const double x)
+  template<typename ElemType>
+  static ElemType Fn(const ElemType x)
   {
-    if (x < DBL_MAX)
-      return x > -DBL_MAX ? x / (1.0 + std::abs(x)) : -1.0;
-    return 1.0;
+    return x / (1 + std::abs(x));
   }
 
   /**
@@ -68,10 +61,7 @@ class SoftsignFunction
   template<typename InputVecType, typename OutputVecType>
   static void Fn(const InputVecType& x, OutputVecType& y)
   {
-    y.set_size(arma::size(x));
-
-    for (size_t i = 0; i < x.n_elem; ++i)
-      y(i) = Fn(x(i));
+    y = x / (1 + abs(x));
   }
 
   /**
@@ -81,9 +71,10 @@ class SoftsignFunction
    * @param y Result of Fn(x).
    * @return f'(x)
    */
-  static double Deriv(const double x, const double /* y */)
+  template<typename ElemType>
+  static ElemType Deriv(const ElemType x, const ElemType /* y */)
   {
-    return 1.0 / std::pow(1.0 + std::abs(x), 2);
+    return 1 / std::pow(1 + std::abs(x), ElemType(2));
   }
 
   /**
@@ -98,7 +89,7 @@ class SoftsignFunction
                     const OutputVecType& /* y */,
                     DerivVecType& dy)
   {
-    dy = 1.0 / pow(1.0 + arma::abs(x), 2);
+    dy = 1 / square(1 + abs(x));
   }
 
   /**
@@ -107,12 +98,13 @@ class SoftsignFunction
    * @param y Input data.
    * @return f^{-1}(y)
    */
-  static double Inv(const double y)
+  template<typename ElemType>
+  static ElemType Inv(const ElemType y)
   {
     if (y > 0)
-      return y < 1 ? -y / (y - 1) : DBL_MAX;
+      return -y / (y - 1);
     else
-      return y > -1 ? y / (1 + y) : -DBL_MAX;
+      return y / (1 + y);
   }
 
   /**
@@ -124,7 +116,7 @@ class SoftsignFunction
   template<typename InputVecType, typename OutputVecType>
   static void Inv(const InputVecType& y, OutputVecType& x)
   {
-    x.set_size(arma::size(y));
+    x.set_size(size(y));
 
     for (size_t i = 0; i < y.n_elem; ++i)
       x(i) = Inv(y(i));
