@@ -16,7 +16,6 @@
 #include <mlpack/prereqs.hpp>
 
 namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
 
 /**
  * This class is used to initialize randomly the weight matrix.
@@ -52,15 +51,17 @@ class RandomInitialization
    * @param rows Number of rows.
    * @param cols Number of columns.
    */
-  template<typename eT>
-  void Initialize(arma::Mat<eT>& W, const size_t rows, const size_t cols)
+  template<typename MatType>
+  void Initialize(MatType& W, const size_t rows, const size_t cols)
   {
+    typedef typename MatType::elem_type ElemType;
+
     if (W.is_empty())
       W.set_size(rows, cols);
 
     W.randu();
-    W *= (upperBound - lowerBound);
-    W += lowerBound;
+    W *= ElemType(upperBound - lowerBound);
+    W += ElemType(lowerBound);
   }
 
   /**
@@ -68,15 +69,18 @@ class RandomInitialization
    *
    * @param W Weight matrix to initialize.
    */
-  template<typename eT>
-  void Initialize(arma::Mat<eT>& W)
+  template<typename MatType>
+  void Initialize(MatType& W,
+      const typename std::enable_if_t<IsMatrix<MatType>::value>* = 0)
   {
+    typedef typename MatType::elem_type ElemType;
+
     if (W.is_empty())
       Log::Fatal << "Cannot initialize an empty matrix." << std::endl;
 
     W.randu();
-    W *= (upperBound - lowerBound);
-    W += lowerBound;
+    W *= ElemType(upperBound - lowerBound);
+    W += ElemType(lowerBound);
   }
 
   /**
@@ -87,8 +91,8 @@ class RandomInitialization
    * @param cols Number of columns.
    * @param slices Number of slices.
    */
-  template<typename eT>
-  void Initialize(arma::Cube<eT>& W,
+  template<typename CubeType>
+  void Initialize(CubeType& W,
                   const size_t rows,
                   const size_t cols,
                   const size_t slices)
@@ -105,8 +109,9 @@ class RandomInitialization
    *
    * @param W Weight matrix to initialize.
    */
-  template<typename eT>
-  void Initialize(arma::Cube<eT>& W)
+  template<typename CubeType>
+  void Initialize(CubeType& W,
+      const typename std::enable_if_t<IsCube<CubeType>::value>* = 0)
   {
     if (W.is_empty())
       Log::Fatal << "Cannot initialize an empty cube." << std::endl;
@@ -115,6 +120,13 @@ class RandomInitialization
       Initialize(W.slice(i));
   }
 
+  template<typename Archive>
+  void serialize(Archive& ar, const uint32_t /* version */)
+  {
+    ar(CEREAL_NVP(lowerBound));
+    ar(CEREAL_NVP(upperBound));
+  }
+
  private:
   //! The number used as lower bound.
   double lowerBound;
@@ -123,7 +135,6 @@ class RandomInitialization
   double upperBound;
 }; // class RandomInitialization
 
-} // namespace ann
 } // namespace mlpack
 
 #endif
