@@ -46,9 +46,12 @@ namespace mlpack {
  *    type to differ from the input type (Default: arma::mat).
  */
 template <typename MatType = arma::mat>
-class HardTanHType : public Layer<MatType>
+class HardTanH : public Layer<MatType>
 {
  public:
+  // Convenience typedef to access the element type of the weights and data.
+  using ElemType = typename MatType::elem_type;
+
   /**
    * Create the HardTanH object using the specified parameters. The range
    * of the linear region can be adjusted by specifying the maxValue and
@@ -57,24 +60,24 @@ class HardTanHType : public Layer<MatType>
    * @param maxValue Range of the linear region maximum value.
    * @param minValue Range of the linear region minimum value.
    */
-  HardTanHType(const double maxValue = 1, const double minValue = -1);
-  
-  virtual ~HardTanHType() { }
+  HardTanH(const double maxValue = 1, const double minValue = -1);
+
+  virtual ~HardTanH() { }
 
   //! Copy the other HardTanH layer
-  HardTanHType(const HardTanHType& layer);
+  HardTanH(const HardTanH& layer);
 
   //! Take ownership of the members of the other HardTanH Layer
-  HardTanHType(HardTanHType&& layer);
+  HardTanH(HardTanH&& layer);
 
   //! Copy the other HardTanH layer
-  HardTanHType& operator=(const HardTanHType& layer);
+  HardTanH& operator=(const HardTanH& layer);
 
   //! Take ownership of the members of the other HardTanH Layer
-  HardTanHType& operator=(HardTanHType&& layer);
+  HardTanH& operator=(HardTanH&& layer);
 
-  //! Clone the HardTanHType object. This handles polymorphism correctly.
-  HardTanHType* Clone() const { return new HardTanHType(*this); }
+  //! Clone the HardTanH object. This handles polymorphism correctly.
+  HardTanH* Clone() const { return new HardTanH(*this); }
 
   /**
    * Ordinary feed forward pass of a neural network, evaluating the function
@@ -122,12 +125,7 @@ class HardTanHType : public Layer<MatType>
 
   //! Minimum value for the HardTanH function.
   double minValue;
-}; // class HardTanHType
-
-// Convenience typedefs.
-
-// Standard HardTanH layer.
-typedef HardTanHType<arma::mat> HardTanH;
+}; // class HardTanH
 
 } // namespace mlpack
 
