@@ -35,7 +35,7 @@ class MaxPoolingRule
   template<typename MatType>
   typename MatType::elem_type Pooling(const MatType& input)
   {
-    return arma::max(arma::vectorise(input));
+    return max(vectorise(input));
   }
 
   template<typename MatType>
@@ -56,11 +56,15 @@ class MaxPoolingRule
  *    computation.
  */
 template<typename MatType = arma::mat>
-class MaxPoolingType : public Layer<MatType>
+class MaxPooling : public Layer<MatType>
 {
  public:
-  //! Create the MaxPooling object.
-  MaxPoolingType();
+  // Convenience typedefs.
+  using ElemType = typename MatType::elem_type;
+  using CubeType = typename GetCubeType<MatType>::type;
+
+  // Create the MaxPooling object.
+  MaxPooling();
 
   /**
    * Create the MaxPooling object using the specified number of units.
@@ -72,26 +76,26 @@ class MaxPoolingType : public Layer<MatType>
    * @param floor If true, then a pooling operation that would oly part of the
    *              input will be skipped.
    */
-  MaxPoolingType(const size_t kernelWidth,
+  MaxPooling(const size_t kernelWidth,
                  const size_t kernelHeight,
                  const size_t strideWidth = 1,
                  const size_t strideHeight = 1,
                  const bool floor = true);
 
   // Virtual destructor.
-  virtual ~MaxPoolingType() { }
+  virtual ~MaxPooling() { }
 
-  //! Copy the given MaxPoolingType.
-  MaxPoolingType(const MaxPoolingType& other);
-  //! Take ownership of the given MaxPoolingType.
-  MaxPoolingType(MaxPoolingType&& other);
-  //! Copy the given MaxPoolingType.
-  MaxPoolingType& operator=(const MaxPoolingType& other);
-  //! Take ownership of the given MaxPoolingType.
-  MaxPoolingType& operator=(MaxPoolingType&& other);
+  //! Copy the given MaxPooling.
+  MaxPooling(const MaxPooling& other);
+  //! Take ownership of the given MaxPooling.
+  MaxPooling(MaxPooling&& other);
+  //! Copy the given MaxPooling.
+  MaxPooling& operator=(const MaxPooling& other);
+  //! Take ownership of the given MaxPooling.
+  MaxPooling& operator=(MaxPooling&& other);
 
-  //! Clone the MaxPoolingType object. This handles polymorphism correctly.
-  MaxPoolingType* Clone() const { return new MaxPoolingType(*this); }
+  //! Clone the MaxPooling object. This handles polymorphism correctly.
+  MaxPooling* Clone() const { return new MaxPooling(*this); }
 
   /**
    * Ordinary feed forward pass of a neural network, evaluating the function
@@ -160,8 +164,8 @@ class MaxPoolingType : public Layer<MatType>
    * @param poolingIndices The pooled indices.
    */
   void PoolingOperation(
-      const arma::Cube<typename MatType::elem_type>& input,
-      arma::Cube<typename MatType::elem_type>& output,
+      const CubeType& input,
+      CubeType& output,
       arma::Cube<size_t>& poolingIndices)
   {
     // Iterate over all slices individually.
@@ -222,8 +226,8 @@ class MaxPoolingType : public Layer<MatType>
    * @param output The pooled result.
    */
   void PoolingOperation(
-      const arma::Cube<typename MatType::elem_type>& input,
-      arma::Cube<typename MatType::elem_type>& output)
+      const CubeType& input,
+      CubeType& output)
   {
     // Iterate over all slices individually.
     #pragma omp parallel for
@@ -305,10 +309,7 @@ class MaxPoolingType : public Layer<MatType>
 
   //! Locally-stored pooling indices.
   arma::Cube<size_t> poolingIndices;
-}; // class MaxPoolingType
-
-// Standard MaxPooling layer.
-typedef MaxPoolingType<arma::mat> MaxPooling;
+}; // class MaxPooling
 
 } // namespace mlpack
 
