@@ -58,6 +58,10 @@ template<typename MatType = arma::mat>
 class RecurrentLayer : public Layer<MatType>
 {
  public:
+  // Convenience typedefs.
+  using ElemType = typename MatType::elem_type;
+  using CubeType = typename GetCubeType<MatType>::type;
+
   /**
    * Create the RecurrentLayer.
    */
@@ -123,6 +127,16 @@ class RecurrentLayer : public Layer<MatType>
   // meant to be done by the enclosing network.)
   void CurrentStep(const size_t& step, const bool end = false);
 
+  /**
+   * Update the internal state of the layer when the step changes. This is
+   * meant to be called by the enclosing network. A child recurrent class
+   * should override this.
+   */
+  virtual void OnStepChanged(const size_t /* step */,
+                             const size_t /* batchSize */,
+                             const size_t /* activeBatchSize */,
+                             const bool /* backwards */) { }
+
   // Get the previous step.  This is a very simple function but can lead to
   // slightly more readable code in Forward(), Backward(), and Gradient()
   // implementations.
@@ -152,10 +166,10 @@ class RecurrentLayer : public Layer<MatType>
   // This holds the recurrent state at each time step for BPTT.  If BPTT is not
   // being used (e.g. if we are only running the network in forward mode and not
   // training), then only one previous time step is held.
-  arma::Cube<typename MatType::elem_type> recurrentState;
+  CubeType recurrentState;
   // This holds the recurrent gradient for BPTT.  If BPTT is not being used,
   // this is empty.
-  arma::Cube<typename MatType::elem_type> recurrentGradient;
+  CubeType recurrentGradient;
 };
 
 } // namespace mlpack
