@@ -9,20 +9,23 @@
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#include <mlpack/prereqs.hpp>
-#include <mlpack/core/util/io.hpp>
-#include <mlpack/methods/neighbor_search/neighbor_search.hpp>
+#include <mlpack/core.hpp>
+
+#undef BINDING_NAME
+#define BINDING_NAME approx_kfn
+
 #include <mlpack/core/util/mlpack_main.hpp>
+#include <mlpack/methods/neighbor_search/neighbor_search.hpp>
+
 #include "drusilla_select.hpp"
 #include "qdafn.hpp"
 
 using namespace mlpack;
-using namespace mlpack::neighbor;
 using namespace mlpack::util;
 using namespace std;
 
 // Program Name.
-BINDING_NAME("Approximate furthest neighbor search");
+BINDING_USER_NAME("Approximate furthest neighbor search");
 
 // Short description.
 BINDING_SHORT_DESC(
@@ -109,14 +112,13 @@ BINDING_EXAMPLE(
 BINDING_SEE_ALSO("k-furthest-neighbor search", "#kfn");
 BINDING_SEE_ALSO("k-nearest-neighbor search", "#knn");
 BINDING_SEE_ALSO("Fast approximate furthest neighbors with data-dependent"
-        " candidate selection (pdf)", "http://ratml.org/pub/pdf/2016fast.pdf");
+    " candidate selection (pdf)", "http://ratml.org/pub/pdf/2016fast.pdf");
 BINDING_SEE_ALSO("Approximate furthest neighbor in high dimensions (pdf)",
-        "https://pdfs.semanticscholar.org/a4b5/7b9cbf37201fb1d9a56c0f4eefad0466"
-        "9c20.pdf");
-BINDING_SEE_ALSO("mlpack::neighbor::QDAFN class documentation",
-        "@doxygen/classmlpack_1_1neighbor_1_1QDAFN.html");
-BINDING_SEE_ALSO("mlpack::neighbor::DrusillaSelect class documentation",
-        "@doxygen/classmlpack_1_1neighbor_1_1DrusillaSelect.html");
+    "https://www.rasmuspagh.net/papers/approx-furthest-neighbor-SISAP15.pdf");
+BINDING_SEE_ALSO("QDAFN class documentation",
+    "@src/mlpack/methods/approx_kfn/qdafn.hpp");
+BINDING_SEE_ALSO("DrusillaSelect class documentation",
+    "@src/mlpack/methods/approx_kfn/drusilla_select.hpp");
 
 PARAM_MATRIX_IN("reference", "Matrix containing the reference dataset.", "r");
 PARAM_MATRIX_IN("query", "Matrix containing query points.", "q");
@@ -151,16 +153,16 @@ class ApproxKFNModel
 
   //! Serialize the model.
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */)
+  void serialize(Archive& ar, const uint32_t /* version */)
   {
-    ar & BOOST_SERIALIZATION_NVP(type);
+    ar(CEREAL_NVP(type));
     if (type == 0)
     {
-      ar & BOOST_SERIALIZATION_NVP(ds);
+      ar(CEREAL_NVP(ds));
     }
     else
     {
-      ar & BOOST_SERIALIZATION_NVP(qdafn);
+      ar(CEREAL_NVP(qdafn));
     }
   }
 };
@@ -171,140 +173,140 @@ PARAM_MODEL_IN(ApproxKFNModel, "input_model", "File containing input model.",
 PARAM_MODEL_OUT(ApproxKFNModel, "output_model", "File to save output model to.",
     "M");
 
-static void mlpackMain()
+void BINDING_FUNCTION(util::Params& params, util::Timers& timers)
 {
   // We have to pass either a reference set or an input model.
-  RequireOnlyOnePassed({ "reference", "input_model" });
+  RequireOnlyOnePassed(params, { "reference", "input_model" });
 
   // Warn if no task will be performed.
-  RequireAtLeastOnePassed({ "reference", "k" }, false,
+  RequireAtLeastOnePassed(params, { "reference", "k" }, false,
       "no task will be performed");
 
   // Warn if no output is going to be saved.
-  RequireAtLeastOnePassed({ "neighbors", "distances", "output_model" }, false,
-      "no output will be saved");
+  RequireAtLeastOnePassed(params, { "neighbors", "distances", "output_model" },
+      false, "no output will be saved");
 
   // Check that the user specified a valid algorithm.
-  RequireParamInSet<string>("algorithm", { "ds", "qdafn" }, true,
+  RequireParamInSet<string>(params, "algorithm", { "ds", "qdafn" }, true,
       "unknown algorithm");
 
   // If we are searching, we need a set to search in.
-  if (IO::HasParam("k"))
+  if (params.Has("k"))
   {
-    RequireAtLeastOnePassed({ "reference", "query" }, true,
+    RequireAtLeastOnePassed(params, { "reference", "query" }, true,
         "if search is being performed, at least one set must be specified");
   }
 
   // Validate parameters.
-  if (IO::HasParam("k"))
+  if (params.Has("k"))
   {
-    RequireParamValue<int>("k", [](int x) { return x > 0; }, true,
+    RequireParamValue<int>(params, "k", [](int x) { return x > 0; }, true,
         "number of neighbors to search for must be positive");
   }
-  RequireParamValue<int>("num_tables", [](int x) { return x > 0; }, true,
-      "number of tables must be positive");
-  RequireParamValue<int>("num_projections", [](int x) { return x > 0; }, true,
-      "number of projections must be positive");
+  RequireParamValue<int>(params, "num_tables", [](int x) { return x > 0; },
+      true, "number of tables must be positive");
+  RequireParamValue<int>(params, "num_projections", [](int x) { return x > 0; },
+      true, "number of projections must be positive");
 
-  ReportIgnoredParam({{ "input_model", true }}, "algorithm");
-  ReportIgnoredParam({{ "input_model", true }}, "num_tables");
-  ReportIgnoredParam({{ "input_model", true }}, "num_projections");
-  ReportIgnoredParam({{ "k", false }}, "calculate_error");
-  ReportIgnoredParam({{ "calculate_error", false }}, "exact_distances");
+  ReportIgnoredParam(params, {{ "input_model", true }}, "algorithm");
+  ReportIgnoredParam(params, {{ "input_model", true }}, "num_tables");
+  ReportIgnoredParam(params, {{ "input_model", true }}, "num_projections");
+  ReportIgnoredParam(params, {{ "k", false }}, "calculate_error");
+  ReportIgnoredParam(params, {{ "calculate_error", false }}, "exact_distances");
 
-  if (IO::HasParam("calculate_error"))
+  if (params.Has("calculate_error"))
   {
-    RequireAtLeastOnePassed({ "exact_distances", "reference" }, true,
+    RequireAtLeastOnePassed(params, { "exact_distances", "reference" }, true,
         "if error is to be calculated, either precalculated exact distances or "
         "the reference set must be passed");
   }
 
-  if (IO::HasParam("k") && IO::HasParam("reference") &&
-      ((size_t) IO::GetParam<int>("k")) >
-          IO::GetParam<arma::mat>("reference").n_cols)
+  if (params.Has("k") && params.Has("reference") &&
+      ((size_t) params.Get<int>("k")) >
+          params.Get<arma::mat>("reference").n_cols)
   {
     Log::Fatal << "Number of neighbors to search for ("
-        << IO::GetParam<int>("k") << ") must be less than the number of "
+        << params.Get<int>("k") << ") must be less than the number of "
         << "reference points ("
-        << IO::GetParam<arma::mat>("reference").n_cols << ")." << std::endl;
+        << params.Get<arma::mat>("reference").n_cols << ")." << std::endl;
   }
 
   // Do the building of a model, if necessary.
   ApproxKFNModel* m;
   arma::mat referenceSet; // This may be used at query time.
-  if (IO::HasParam("reference"))
+  if (params.Has("reference"))
   {
-    referenceSet = std::move(IO::GetParam<arma::mat>("reference"));
+    referenceSet = std::move(params.Get<arma::mat>("reference"));
     m = new ApproxKFNModel();
 
-    const size_t numTables = (size_t) IO::GetParam<int>("num_tables");
+    const size_t numTables = (size_t) params.Get<int>("num_tables");
     const size_t numProjections =
-        (size_t) IO::GetParam<int>("num_projections");
-    const string algorithm = IO::GetParam<string>("algorithm");
+        (size_t) params.Get<int>("num_projections");
+    const string algorithm = params.Get<string>("algorithm");
 
     if (algorithm == "ds")
     {
-      Timer::Start("drusilla_select_construct");
+      timers.Start("drusilla_select_construct");
       Log::Info << "Building DrusillaSelect model..." << endl;
       m->type = 0;
       m->ds = DrusillaSelect<>(referenceSet, numTables, numProjections);
-      Timer::Stop("drusilla_select_construct");
+      timers.Stop("drusilla_select_construct");
     }
     else
     {
-      Timer::Start("qdafn_construct");
+      timers.Start("qdafn_construct");
       Log::Info << "Building QDAFN model..." << endl;
       m->type = 1;
       m->qdafn = QDAFN<>(referenceSet, numTables, numProjections);
-      Timer::Stop("qdafn_construct");
+      timers.Stop("qdafn_construct");
     }
     Log::Info << "Model built." << endl;
   }
   else
   {
     // We must load the model from what was passed.
-    m = IO::GetParam<ApproxKFNModel*>("input_model");
+    m = params.Get<ApproxKFNModel*>("input_model");
   }
 
   // Now, do we need to do any queries?
-  if (IO::HasParam("k"))
+  if (params.Has("k"))
   {
     arma::mat querySet; // This may or may not be used.
-    const size_t k = (size_t) IO::GetParam<int>("k");
+    const size_t k = (size_t) params.Get<int>("k");
 
     arma::Mat<size_t> neighbors;
     arma::mat distances;
 
-    arma::mat& set = IO::HasParam("query") ? querySet : referenceSet;
-    if (IO::HasParam("query"))
-      querySet = std::move(IO::GetParam<arma::mat>("query"));
+    arma::mat& set = params.Has("query") ? querySet : referenceSet;
+    if (params.Has("query"))
+      querySet = std::move(params.Get<arma::mat>("query"));
 
     if (m->type == 0)
     {
-      Timer::Start("drusilla_select_search");
+      timers.Start("drusilla_select_search");
       Log::Info << "Searching for " << k << " furthest neighbors with "
           << "DrusillaSelect..." << endl;
       m->ds.Search(set, k, neighbors, distances);
-      Timer::Stop("drusilla_select_search");
+      timers.Stop("drusilla_select_search");
     }
     else
     {
-      Timer::Start("qdafn_search");
+      timers.Start("qdafn_search");
       Log::Info << "Searching for " << k << " furthest neighbors with "
           << "QDAFN..." << endl;
       m->qdafn.Search(set, k, neighbors, distances);
-      Timer::Stop("qdafn_search");
+      timers.Stop("qdafn_search");
     }
     Log::Info << "Search complete." << endl;
 
     // Should we calculate error?
-    if (IO::HasParam("calculate_error"))
+    if (params.Has("calculate_error"))
     {
       arma::mat exactDistances;
-      if (IO::HasParam("exact_distances"))
+      if (params.Has("exact_distances"))
       {
         // Check the exact distances matrix has the right dimensions.
-        exactDistances = std::move(IO::GetParam<arma::mat>("exact_distances"));
+        exactDistances = std::move(params.Get<arma::mat>("exact_distances"));
 
         if (exactDistances.n_rows != k)
         {
@@ -333,11 +335,11 @@ static void mlpackMain()
         Log::Info << "Calculation complete." << endl;
       }
 
-      const double averageError = arma::sum(exactDistances.row(0) /
+      const double averageError = sum(exactDistances.row(0) /
           distances.row(0)) / distances.n_cols;
-      const double minError = arma::min(exactDistances.row(0) /
+      const double minError = min(exactDistances.row(0) /
           distances.row(0));
-      const double maxError = arma::max(exactDistances.row(0) /
+      const double maxError = max(exactDistances.row(0) /
           distances.row(0));
 
       Log::Info << "Average error: " << averageError << "." << endl;
@@ -346,9 +348,9 @@ static void mlpackMain()
     }
 
     // Save results, if desired.
-    IO::GetParam<arma::Mat<size_t>>("neighbors") = std::move(neighbors);
-    IO::GetParam<arma::mat>("distances") = std::move(distances);
+    params.Get<arma::Mat<size_t>>("neighbors") = std::move(neighbors);
+    params.Get<arma::mat>("distances") = std::move(distances);
   }
 
-  IO::GetParam<ApproxKFNModel*>("output_model") = m;
+  params.Get<ApproxKFNModel*>("output_model") = m;
 }
