@@ -45,7 +45,7 @@ DecisionTreeRegressor<FitnessFunction,
                       DimensionSelectionType,
                       NoRecursion>::DecisionTreeRegressor(
     MatType data,
-    const data::DatasetInfo& datasetInfo,
+    const DatasetInfo& datasetInfo,
     ResponsesType responses,
     const size_t minimumLeafSize,
     const double minimumGainSplit,
@@ -117,7 +117,7 @@ DecisionTreeRegressor<FitnessFunction,
                       DimensionSelectionType,
                       NoRecursion>::DecisionTreeRegressor(
     MatType data,
-    const data::DatasetInfo& datasetInfo,
+    const DatasetInfo& datasetInfo,
     ResponsesType responses,
     WeightsType weights,
     const size_t minimumLeafSize,
@@ -199,7 +199,7 @@ DecisionTreeRegressor<FitnessFunction,
                       NoRecursion>::DecisionTreeRegressor(
     const DecisionTreeRegressor& other,
     MatType data,
-    const data::DatasetInfo& datasetInfo,
+    const DatasetInfo& datasetInfo,
     ResponsesType responses,
     WeightsType weights,
     const size_t minimumLeafSize,
@@ -429,7 +429,7 @@ double DecisionTreeRegressor<FitnessFunction,
                              DimensionSelectionType,
                              NoRecursion>::Train(
     MatType data,
-    const data::DatasetInfo& datasetInfo,
+    const DatasetInfo& datasetInfo,
     ResponsesType responses,
     const size_t minimumLeafSize,
     const double minimumGainSplit,
@@ -510,7 +510,7 @@ double DecisionTreeRegressor<FitnessFunction,
                              DimensionSelectionType,
                              NoRecursion>::Train(
     MatType data,
-    const data::DatasetInfo& datasetInfo,
+    const DatasetInfo& datasetInfo,
     ResponsesType responses,
     WeightsType weights,
     const size_t minimumLeafSize,
@@ -601,7 +601,7 @@ double DecisionTreeRegressor<FitnessFunction,
     MatType& data,
     const size_t begin,
     const size_t count,
-    const data::DatasetInfo& datasetInfo,
+    const DatasetInfo& datasetInfo,
     ResponsesType& responses,
     arma::rowvec& weights,
     const size_t minimumLeafSize,
@@ -630,7 +630,7 @@ double DecisionTreeRegressor<FitnessFunction,
          i = dimensionSelector.Next())
     {
       double dimGain = -DBL_MAX;
-      if (datasetInfo.Type(i) == data::Datatype::categorical)
+      if (datasetInfo.Type(i) == Datatype::categorical)
       {
         dimGain = CategoricalSplit::template SplitIfBetter<UseWeights>(bestGain,
             data.cols(begin, begin + count - 1).row(i),
@@ -643,7 +643,7 @@ double DecisionTreeRegressor<FitnessFunction,
             *this,
             fitnessFunction);
       }
-      else if (datasetInfo.Type(i) == data::Datatype::numeric)
+      else if (datasetInfo.Type(i) == Datatype::numeric)
       {
         dimGain = NumericSplit::template SplitIfBetter<UseWeights>(bestGain,
             data.cols(begin, begin + count - 1).row(i),
@@ -679,14 +679,14 @@ double DecisionTreeRegressor<FitnessFunction,
 
     // Get the number of children we will have.
     size_t numChildren = 0;
-    if (datasetInfo.Type(bestDim) == data::Datatype::categorical)
+    if (datasetInfo.Type(bestDim) == Datatype::categorical)
       numChildren = CategoricalSplit::NumChildren(splitInfo, *this);
     else
       numChildren = NumericSplit::NumChildren(splitInfo, *this);
 
     // Calculate all child assignments.
     arma::Row<size_t> childAssignments(count);
-    if (datasetInfo.Type(bestDim) == data::Datatype::categorical)
+    if (datasetInfo.Type(bestDim) == Datatype::categorical)
     {
       for (size_t j = begin; j < begin + count; ++j)
         childAssignments[j - begin] = CategoricalSplit::CalculateDirection(
@@ -844,7 +844,7 @@ double DecisionTreeRegressor<FitnessFunction,
     // We know that the split is numeric.
     size_t numChildren = NumericSplit::NumChildren(splitInfo, *this);
     splitDimension = bestDim;
-    dimensionType = (size_t) data::Datatype::numeric;
+    dimensionType = (size_t) Datatype::numeric;
 
     // Calculate all child assignments.
     arma::Row<size_t> childAssignments(count);
@@ -986,7 +986,7 @@ size_t DecisionTreeRegressor<FitnessFunction,
                              NoRecursion
 >::CalculateDirection(const VecType& point) const
 {
-  if ((data::Datatype) dimensionType == data::Datatype::categorical)
+  if ((Datatype) dimensionType == Datatype::categorical)
     return CategoricalSplit::CalculateDirection(point[splitDimension],
         splitInfo, *this);
   else
