@@ -288,7 +288,7 @@ void LinearSVMFunction<MatType, ParametersType>::Gradient(
   }
   else
   {
-    gradient.set_size(arma::size(parameters));
+    gradient.set_size(size(parameters));
     gradient.submat(0, 0, parameters.n_rows - 2, parameters.n_cols - 1) =
         dataset * difference.t();
     gradient.row(parameters.n_rows - 1) =
@@ -345,7 +345,7 @@ void LinearSVMFunction<MatType, ParametersType>::Gradient(
   }
   else
   {
-    gradient.set_size(arma::size(parameters));
+    gradient.set_size(size(parameters));
     gradient.submat(0, 0, parameters.n_rows - 2, parameters.n_cols - 1) =
         dataset.cols(firstId, lastId) * difference.t();
     gradient.row(parameters.n_rows - 1) =
@@ -400,7 +400,7 @@ LinearSVMFunction<MatType, ParametersType>::EvaluateWithGradient(
   }
   else
   {
-    gradient.set_size(arma::size(parameters));
+    gradient.set_size(size(parameters));
     gradient.submat(0, 0, parameters.n_rows - 2, parameters.n_cols - 1) =
             dataset * difference.t();
     gradient.row(parameters.n_rows - 1) =
@@ -472,7 +472,7 @@ LinearSVMFunction<MatType, ParametersType>::EvaluateWithGradient(
   }
   else
   {
-    gradient.set_size(arma::size(parameters));
+    gradient.set_size(size(parameters));
     gradient.submat(0, 0, parameters.n_rows - 2, parameters.n_cols - 1) =
         dataset.cols(firstId, lastId) * difference.t();
     gradient.row(parameters.n_rows - 1) =
