@@ -1,5 +1,5 @@
 /**
- * @file ra_search.hpp
+ * @file methods/rann/ra_search.hpp
  * @author Parikshit Ram
  *
  * Defines the RASearch class, which performs an abstract rank-approximate
@@ -7,6 +7,7 @@
  *
  * The details of this method can be found in the following paper:
  *
+ * @code
  * @inproceedings{ram2009rank,
  *   title={{Rank-Approximate Nearest Neighbor Search: Retaining Meaning and
  *       Speed in High Dimensions}},
@@ -14,6 +15,7 @@
  *   booktitle={{Advances of Neural Information Processing Systems}},
  *   year={2009}
  * }
+ * @endcode
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
@@ -23,22 +25,20 @@
 #ifndef MLPACK_METHODS_RANN_RA_SEARCH_HPP
 #define MLPACK_METHODS_RANN_RA_SEARCH_HPP
 
-#include <mlpack/prereqs.hpp>
+#include <mlpack/core.hpp>
 
-#include <mlpack/core/tree/binary_space_tree.hpp>
-
-#include <mlpack/core/metrics/lmetric.hpp>
 #include <mlpack/methods/neighbor_search/sort_policies/nearest_neighbor_sort.hpp>
 
 #include "ra_query_stat.hpp"
 #include "ra_util.hpp"
 
 namespace mlpack {
-namespace neighbor {
 
 // Forward declaration.
-template<typename SortPolicy>
-class TrainVisitor;
+template<template<typename TreeDistanceType,
+                  typename TreeStatType,
+                  typename TreeMatType> class TreeType>
+class LeafSizeRAWrapper;
 
 /**
  * The RASearch class: This class provides a generic manner to perform
@@ -48,6 +48,7 @@ class TrainVisitor;
  * stratified manner in the tree as mentioned in the algorithms in Figure 2 of
  * the following paper:
  *
+ * @code
  * @inproceedings{ram2009rank,
  *   title={{Rank-Approximate Nearest Neighbor Search: Retaining Meaning and
  *       Speed in High Dimensions}},
@@ -55,30 +56,31 @@ class TrainVisitor;
  *   booktitle={{Advances of Neural Information Processing Systems}},
  *   year={2009}
  * }
+ * @endcode
  *
  * RASearch is currently known to not work with ball trees (#356).
  *
  * @tparam SortPolicy The sort policy for distances; see NearestNeighborSort.
- * @tparam MetricType The metric to use for computation.
+ * @tparam DistanceType The distance metric to use for computation.
  * @tparam TreeType The tree type to use.
  */
 template<typename SortPolicy = NearestNeighborSort,
-         typename MetricType = metric::EuclideanDistance,
+         typename DistanceType = EuclideanDistance,
          typename MatType = arma::mat,
-         template<typename TreeMetricType,
+         template<typename TreeDistanceType,
                   typename TreeStatType,
-                  typename TreeMatType> class TreeType = tree::KDTree>
+                  typename TreeMatType> class TreeType = KDTree>
 class RASearch
 {
  public:
   //! Convenience typedef.
-  typedef TreeType<MetricType, RAQueryStat<SortPolicy>, MatType> Tree;
+  using Tree = TreeType<DistanceType, RAQueryStat<SortPolicy>, MatType>;
 
   /**
    * Initialize the RASearch object, passing both a reference dataset (this is
    * the dataset that will be searched).  Optionally, perform the computation in
    * naive mode or single-tree mode.  An initialized distance metric can be
-   * given, for cases where the metric has internal data (i.e. the
+   * given, for cases where the distance metric has internal data (i.e. the
    * distance::MahalanobisDistance class).
    *
    * This method will copy the matrices to internal copies, which are rearranged
@@ -107,7 +109,7 @@ class RASearch
    * @param singleMode If true, single-tree search will be used (as opposed to
    *      dual-tree search).  This is useful when Search() will be called with
    *      few query points.
-   * @param metric An optional instance of the MetricType class.
+   * @param distance An optional instance of the DistanceType class.
    * @param tau The rank-approximation in percentile of the data. The default
    *     value is 5%.
    * @param alpha The desired success probability. The default value is 0.95.
@@ -127,7 +129,7 @@ class RASearch
            const bool sampleAtLeaves = false,
            const bool firstLeafExact = false,
            const size_t singleSampleLimit = 20,
-           const MetricType metric = MetricType());
+           const DistanceType distance = DistanceType());
 
   /**
    * Initialize the RASearch object with the given pre-constructed reference
@@ -160,7 +162,6 @@ class RASearch
    * Tree-building may (at least with BinarySpaceTree) modify the ordering
    * of a matrix, so be aware that the results you get from Search() will
    * correspond to the modified matrix.
-   * @endnote
    *
    * @param referenceTree Pre-built tree for reference points.
    * @param singleMode Whether single-tree computation should be used (as
@@ -175,7 +176,7 @@ class RASearch
    *     if there exists one.  This defaults to 'false' for now.
    * @param singleSampleLimit The limit on the largest node that can be
    *     approximated by sampling. This defaults to 20.
-   * @param metric Instantiated distance metric.
+   * @param distance Instantiated distance metric.
    */
   RASearch(Tree* referenceTree,
            const bool singleMode = false,
@@ -184,7 +185,7 @@ class RASearch
            const bool sampleAtLeaves = false,
            const bool firstLeafExact = false,
            const size_t singleSampleLimit = 20,
-           const MetricType metric = MetricType());
+           const DistanceType distance = DistanceType());
 
   /**
    * Create an RASearch object with no reference data.  If Search() is called
@@ -203,7 +204,7 @@ class RASearch
    *     if there exists one.  This defaults to 'false' for now.
    * @param singleSampleLimit The limit on the largest node that can be
    *     approximated by sampling. This defaults to 20.
-   * @param metric Instantiated distance metric.
+   * @param distance Instantiated distance metric.
    */
   RASearch(const bool naive = false,
            const bool singleMode = false,
@@ -212,7 +213,7 @@ class RASearch
            const bool sampleAtLeaves = false,
            const bool firstLeafExact = false,
            const size_t singleSampleLimit = 20,
-           const MetricType metric = MetricType());
+           const DistanceType distance = DistanceType());
 
   /**
    * Delete the RASearch object. The tree is the only member we are
@@ -272,7 +273,6 @@ class RASearch
    * If the tree type you are using modifies the data matrix, be aware that the
    * results returned from this function will be with respect to the modified
    * data matrix.
-   * @endnote
    *
    * @param queryTree Tree built on query points.
    * @param k Number of neighbors to search for.
@@ -356,7 +356,7 @@ class RASearch
 
   //! Serialize the object.
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
   //! Permutations of reference points during tree building.
@@ -388,15 +388,13 @@ class RASearch
   //! approximated by sampling.
   size_t singleSampleLimit;
 
-  //! Instantiation of kernel.
-  MetricType metric;
+  //! Instantiation of distance metric.
+  DistanceType distance;
 
   //! For access to mappings when building models.
-  template<typename SortPol>
-  friend class TrainVisitor;
+  friend class LeafSizeRAWrapper<TreeType>;
 }; // class RASearch
 
-} // namespace neighbor
 } // namespace mlpack
 
 // Include implementation.
