@@ -20,8 +20,7 @@ inline void MaximalInputs(const arma::mat& parameters, arma::mat& output)
 {
   arma::mat paramTemp(parameters.submat(0, 0, (parameters.n_rows - 1) / 2 - 1,
                                         parameters.n_cols - 2).t());
-  double const mean = arma::mean(arma::mean(paramTemp));
-  paramTemp -= mean;
+  paramTemp -= arma::mean(arma::mean(paramTemp));
 
   NormalizeColByMax(paramTemp, output);
 }
@@ -32,10 +31,10 @@ inline void NormalizeColByMax(const arma::mat &input,
   output.set_size(input.n_rows, input.n_cols);
   for (arma::uword i = 0; i != input.n_cols; ++i)
   {
-    const double max = arma::max(arma::abs(input.col(i)));
-    if (max != 0.0)
+    const double colMax = max(arma::abs(input.col(i)));
+    if (colMax != 0.0)
     {
-      output.col(i) = input.col(i) / max;
+      output.col(i) = input.col(i) / colMax;
     }
     else
     {
