@@ -17,19 +17,19 @@
 #include <mlpack/core/math/make_alias.hpp>
 
 namespace mlpack {
-namespace svd {
 
 template <typename MatType>
 SVDPlusPlusFunction<MatType>::SVDPlusPlusFunction(
-    const MatType& data,
+    const MatType& dataIn,
     const arma::sp_mat& implicitData,
     const size_t rank,
     const double lambda) :
-    data(math::MakeAlias(const_cast<MatType&>(data), false)),
     implicitData(implicitData),
     rank(rank),
     lambda(lambda)
 {
+  MakeAlias(data, dataIn, dataIn.n_rows, dataIn.n_cols, false);
+
   // Number of users and items in the data.
   numUsers = max(data.row(0)) + 1;
   numItems = max(data.row(1)) + 1;
@@ -96,7 +96,7 @@ double SVDPlusPlusFunction<MatType>::Evaluate(const arma::mat& parameters,
 
     // Iterate through each item which the user interacted with to calculate
     // user vector.
-    arma::vec userVec(rank, arma::fill::zeros);
+    arma::vec userVec(rank);
     arma::sp_mat::const_iterator it = implicitData.begin_col(user);
     arma::sp_mat::const_iterator it_end = implicitData.end_col(user);
     size_t implicitCount = 0;
@@ -106,7 +106,7 @@ double SVDPlusPlusFunction<MatType>::Evaluate(const arma::mat& parameters,
       userVec += parameters.col(implicitStart + it.row()).subvec(0, rank - 1);
       if (implicitVecsNormSquare(it.row()) < 0)
       {
-        implicitVecsNormSquare(it.row()) = arma::dot(
+        implicitVecsNormSquare(it.row()) = dot(
             parameters.col(implicitStart + it.row()).subvec(0, rank - 1),
             parameters.col(implicitStart + it.row()).subvec(0, rank - 1));
       }
@@ -121,12 +121,12 @@ double SVDPlusPlusFunction<MatType>::Evaluate(const arma::mat& parameters,
     userVec += parameters.col(user).subvec(0, rank - 1);
 
     double ratingError = rating - userBias - itemBias -
-        arma::dot(userVec, parameters.col(item).subvec(0, rank - 1));
+        dot(userVec, parameters.col(item).subvec(0, rank - 1));
     double ratingErrorSquared = ratingError * ratingError;
 
     // Calculate the regularization penalty corresponding to the parameters.
-    double userVecNorm = arma::norm(parameters.col(user), 2);
-    double itemVecNorm = arma::norm(parameters.col(item), 2);
+    double userVecNorm = norm(parameters.col(user), 2);
+    double itemVecNorm = norm(parameters.col(item), 2);
     regularizationError += lambda * (userVecNorm * userVecNorm +
                                      itemVecNorm * itemVecNorm);
 
@@ -169,7 +169,7 @@ void SVDPlusPlusFunction<MatType>::Gradient(const arma::mat& parameters,
 
     // Iterate through each item which the user interacted with to calculate
     // user vector.
-    arma::vec userVec(rank, arma::fill::zeros);
+    arma::vec userVec(rank);
     arma::sp_mat::const_iterator it = implicitData.begin_col(user);
     arma::sp_mat::const_iterator it_end = implicitData.end_col(user);
     size_t implicitCount = 0;
@@ -183,7 +183,7 @@ void SVDPlusPlusFunction<MatType>::Gradient(const arma::mat& parameters,
     userVec += parameters.col(user).subvec(0, rank - 1);
 
     double ratingError = rating - userBias - itemBias -
-        arma::dot(userVec, parameters.col(item).subvec(0, rank - 1));
+        dot(userVec, parameters.col(item).subvec(0, rank - 1));
 
     // Gradient is non-zero only for the parameter columns corresponding to the
     // example.
@@ -236,7 +236,7 @@ void SVDPlusPlusFunction<MatType>::Gradient(const arma::mat& parameters,
 
     // Iterate through each item which the user interacted with to calculate
     // user vector.
-    arma::vec userVec(rank, arma::fill::zeros);
+    arma::vec userVec(rank);
     arma::sp_mat::const_iterator it = implicitData.begin_col(user);
     arma::sp_mat::const_iterator it_end = implicitData.end_col(user);
     size_t implicitCount = 0;
@@ -250,7 +250,7 @@ void SVDPlusPlusFunction<MatType>::Gradient(const arma::mat& parameters,
     userVec += parameters.col(user).subvec(0, rank - 1);
 
     double ratingError = rating - userBias - itemBias -
-        arma::dot(userVec, parameters.col(item).subvec(0, rank - 1));
+        dot(userVec, parameters.col(item).subvec(0, rank - 1));
 
     // Gradient is non-zero only for the parameter columns corresponding to the
     // example.
@@ -285,7 +285,6 @@ void SVDPlusPlusFunction<MatType>::Gradient(const arma::mat& parameters,
   }
 }
 
-} // namespace svd
 } // namespace mlpack
 
 // Template specialization for the SGD optimizer.
@@ -294,7 +293,7 @@ namespace ens {
 template <>
 template <>
 double StandardSGD::Optimize(
-    mlpack::svd::SVDPlusPlusFunction<arma::mat>& function,
+    mlpack::SVDPlusPlusFunction<arma::mat>& function,
     arma::mat& parameters)
 {
   // Find the number of functions to use.
@@ -344,7 +343,7 @@ double StandardSGD::Optimize(
 
     // Iterate through each item which the user interacted with to calculate
     // user vector.
-    arma::vec userVec(rank, arma::fill::zeros);
+    arma::vec userVec(rank);
     arma::sp_mat::const_iterator it = implicitData.begin_col(user);
     arma::sp_mat::const_iterator it_end = implicitData.end_col(user);
     size_t implicitCount = 0;
@@ -358,7 +357,7 @@ double StandardSGD::Optimize(
     userVec += parameters.col(user).subvec(0, rank - 1);
 
     double ratingError = rating - userBias - itemBias -
-        arma::dot(userVec, parameters.col(item).subvec(0, rank - 1));
+        dot(userVec, parameters.col(item).subvec(0, rank - 1));
 
     // Gradient is non-zero only for the parameter columns corresponding to the
     // example.
@@ -396,7 +395,7 @@ double StandardSGD::Optimize(
 template <>
 template <>
 inline double ParallelSGD<ExponentialBackoff>::Optimize(
-    mlpack::svd::SVDPlusPlusFunction<arma::mat>& function,
+    mlpack::SVDPlusPlusFunction<arma::mat>& function,
     arma::mat& iterate)
 {
   double overallObjective = DBL_MAX;
@@ -425,7 +424,7 @@ inline double ParallelSGD<ExponentialBackoff>::Optimize(
     overallObjective = 0;
 
     #pragma omp parallel for reduction(+:overallObjective)
-    for (omp_size_t j = 0; j < (omp_size_t) function.NumFunctions(); ++j)
+    for (size_t j = 0; j < (size_t) function.NumFunctions(); ++j)
     {
       overallObjective += function.Evaluate(iterate, j);
     }
@@ -452,16 +451,16 @@ inline double ParallelSGD<ExponentialBackoff>::Optimize(
     // Get the stepsize for this iteration
     double stepSize = decayPolicy.StepSize(i);
 
-    if (shuffle) // Determine order of visitation.
+    if (Shuffle()) // Determine order of visitation.
       std::shuffle(visitationOrder.begin(), visitationOrder.end(),
-          mlpack::math::randGen);
+          mlpack::RandGen());
 
     #pragma omp parallel
     {
       // Each processor gets a subset of the instances.
       // Each subset is of size threadShareSize.
       size_t threadId = 0;
-      #ifdef HAS_OPENMP
+      #ifdef MLPACK_USE_OPENMP
         threadId = omp_get_thread_num();
       #endif
 
@@ -480,7 +479,7 @@ inline double ParallelSGD<ExponentialBackoff>::Optimize(
         const double itemBias = iterate(rank, item);
         // Iterate through each item which the user interacted with to calculate
         // user vector.
-        arma::vec userVec(rank, arma::fill::zeros);
+        arma::vec userVec(rank);
         arma::sp_mat::const_iterator it = implicitData.begin_col(user);
         arma::sp_mat::const_iterator it_end = implicitData.end_col(user);
         size_t implicitCount = 0;
@@ -494,7 +493,7 @@ inline double ParallelSGD<ExponentialBackoff>::Optimize(
         userVec += iterate.col(user).subvec(0, rank - 1);
 
         double ratingError = rating - userBias - itemBias -
-        arma::dot(userVec, iterate.col(item).subvec(0, rank - 1));
+        dot(userVec, iterate.col(item).subvec(0, rank - 1));
 
         arma::mat userVecUpdate = stepSize * 2 * (
             lambda * iterate.col(user).subvec(0, rank - 1) -
