@@ -24,18 +24,18 @@ using namespace mlpack;
  * checks whether the hamming loss breaches the upperbound, which is provided by
  * ztAccumulator.
  */
-TEMPLATE_TEST_CASE("HammingLossBoundIris", "[AdaBoostTest]", mat, fmat)
+TEMPLATE_TEST_CASE("HammingLossBoundIris", "[AdaBoostTest][tiny]", mat, fmat)
 {
   using MatType = TestType;
   using eT = typename MatType::elem_type;
 
   MatType inputData;
 
-  if (!data::Load("iris.csv", inputData))
+  if (!Load("iris.csv", inputData))
     FAIL("Cannot load test dataset iris.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("iris_labels.txt", labels))
+  if (!Load("iris_labels.txt", labels))
     FAIL("Cannot load labels for iris iris_labels.txt");
 
   const size_t numClasses = max(labels.row(0)) + 1;
@@ -75,11 +75,11 @@ TEMPLATE_TEST_CASE("WeakLearnerErrorIris", "[AdaBoostTest]", mat, fmat)
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("iris.csv", inputData))
+  if (!Load("iris.csv", inputData))
     FAIL("Cannot load test dataset iris.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("iris_labels.txt", labels))
+  if (!Load("iris_labels.txt", labels))
     FAIL("Cannot load labels for iris iris_labels.txt");
 
   const size_t numClasses = max(labels.row(0)) + 1;
@@ -124,11 +124,11 @@ TEMPLATE_TEST_CASE("HammingLossBoundVertebralColumn", "[AdaBoostTest]", mat,
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("vc2.csv", inputData))
+  if (!Load("vc2.csv", inputData))
     FAIL("Cannot load test dataset vc2.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("vc2_labels.txt", labels))
+  if (!Load("vc2_labels.txt", labels))
     FAIL("Cannot load labels for vc2_labels.txt");
 
   const size_t numClasses = max(labels.row(0)) + 1;
@@ -170,11 +170,11 @@ TEMPLATE_TEST_CASE("WeakLearnerErrorVertebralColumn", "[AdaBoostTest]", mat,
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("vc2.csv", inputData))
+  if (!Load("vc2.csv", inputData))
     FAIL("Cannot load test dataset vc2.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("vc2_labels.txt", labels))
+  if (!Load("vc2_labels.txt", labels))
     FAIL("Cannot load labels for vc2_labels.txt");
 
   const size_t numClasses = max(labels.row(0)) + 1;
@@ -219,11 +219,11 @@ TEMPLATE_TEST_CASE("HammingLossBoundNonLinearSepData", "[AdaBoostTest]", mat,
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("train_nonlinsep.txt", inputData))
+  if (!Load("train_nonlinsep.txt", inputData))
     FAIL("Cannot load test dataset train_nonlinsep.txt!");
 
   Mat<size_t> labels;
-  if (!data::Load("train_labels_nonlinsep.txt", labels))
+  if (!Load("train_labels_nonlinsep.txt", labels))
     FAIL("Cannot load labels for train_labels_nonlinsep.txt");
 
   const size_t numClasses = max(labels.row(0)) + 1;
@@ -258,18 +258,18 @@ TEMPLATE_TEST_CASE("HammingLossBoundNonLinearSepData", "[AdaBoostTest]", mat,
  * dataset.  It checks if the error returned by running a single instance of the
  * weak learner is close to that of a boosted weak learner using AdaBoost.
  */
-TEMPLATE_TEST_CASE("WeakLearnerErrorNonLinearSepData", "[AdaBoostTest]", mat,
-    fmat)
+TEMPLATE_TEST_CASE("WeakLearnerErrorNonLinearSepData", "[AdaBoostTest][long]",
+    mat, fmat)
 {
   using MatType = TestType;
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("train_nonlinsep.txt", inputData))
+  if (!Load("train_nonlinsep.txt", inputData))
     FAIL("Cannot load test dataset train_nonlinsep.txt!");
 
   Mat<size_t> labels;
-  if (!data::Load("train_labels_nonlinsep.txt", labels))
+  if (!Load("train_labels_nonlinsep.txt", labels))
     FAIL("Cannot load labels for train_labels_nonlinsep.txt");
 
   const size_t numClasses = max(labels.row(0)) + 1;
@@ -313,11 +313,11 @@ TEMPLATE_TEST_CASE("HammingLossIris_DS", "[AdaBoostTest]", mat, fmat)
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("iris.csv", inputData))
+  if (!Load("iris.csv", inputData))
     FAIL("Cannot load test dataset iris.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("iris_labels.txt", labels))
+  if (!Load("iris_labels.txt", labels))
     FAIL("Cannot load labels for iris_labels.txt");
 
   // Define your own weak learner, decision stumps in this case.
@@ -349,17 +349,17 @@ TEMPLATE_TEST_CASE("HammingLossIris_DS", "[AdaBoostTest]", mat, fmat)
  * weak learner is close to that of a boosted weak learner using adaboost.
  * This is for the weak learner: decision stumps.
  */
-TEMPLATE_TEST_CASE("WeakLearnerErrorIris_DS", "[AdaBoostTest]", mat, fmat)
+TEMPLATE_TEST_CASE("WeakLearnerErrorIris_DS", "[AdaBoostTest][tiny]", mat, fmat)
 {
   using MatType = TestType;
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("iris.csv", inputData))
+  if (!Load("iris.csv", inputData))
     FAIL("Cannot load test dataset iris.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("iris_labels.txt", labels))
+  if (!Load("iris_labels.txt", labels))
     FAIL("Cannot load labels for iris_labels.txt");
 
   // no need to map the labels here
@@ -406,11 +406,11 @@ TEMPLATE_TEST_CASE("HammingLossBoundVertebralColumn_DS", "[AdaBoostTest]", mat,
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("vc2.csv", inputData))
+  if (!Load("vc2.csv", inputData))
     FAIL("Cannot load test dataset vc2.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("vc2_labels.txt", labels))
+  if (!Load("vc2_labels.txt", labels))
     FAIL("Cannot load labels for vc2_labels.txt");
 
   // Define your own weak learner, decision stumps in this case.
@@ -452,11 +452,11 @@ TEMPLATE_TEST_CASE("WeakLearnerErrorVertebralColumn_DS", "[AdaBoostTest]", mat,
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("vc2.csv", inputData))
+  if (!Load("vc2.csv", inputData))
     FAIL("Cannot load test dataset vc2.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("vc2_labels.txt", labels))
+  if (!Load("vc2_labels.txt", labels))
     FAIL("Cannot load labels for vc2_labels.txt");
 
   // Define your own weak learner, decision stumps in this case.
@@ -491,18 +491,18 @@ TEMPLATE_TEST_CASE("WeakLearnerErrorVertebralColumn_DS", "[AdaBoostTest]", mat,
  * dataset.  It checks whether the hamming loss breaches the upperbound, which
  * is provided by ztAccumulator.  This is for the weak learner: decision stumps.
  */
-TEMPLATE_TEST_CASE("HammingLossBoundNonLinearSepData_DS", "[AdaBoostTest]", mat,
-    fmat)
+TEMPLATE_TEST_CASE("HammingLossBoundNonLinearSepData_DS",
+    "[AdaBoostTest][long]", mat, fmat)
 {
   using MatType = TestType;
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("train_nonlinsep.txt", inputData))
+  if (!Load("train_nonlinsep.txt", inputData))
     FAIL("Cannot load test dataset train_nonlinsep.txt!");
 
   Mat<size_t> labels;
-  if (!data::Load("train_labels_nonlinsep.txt", labels))
+  if (!Load("train_labels_nonlinsep.txt", labels))
     FAIL("Cannot load labels for train_labels_nonlinsep.txt");
 
   // Define your own weak learner, decision stumps in this case.
@@ -544,11 +544,11 @@ TEMPLATE_TEST_CASE("WeakLearnerErrorNonLinearSepData_DS", "[AdaBoostTest]", mat,
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("train_nonlinsep.txt", inputData))
+  if (!Load("train_nonlinsep.txt", inputData))
     FAIL("Cannot load test dataset train_nonlinsep.txt!");
 
   Mat<size_t> labels;
-  if (!data::Load("train_labels_nonlinsep.txt", labels))
+  if (!Load("train_labels_nonlinsep.txt", labels))
     FAIL("Cannot load labels for train_labels_nonlinsep.txt");
 
   // Define your own weak learner, decision stumps in this case.
@@ -585,17 +585,18 @@ TEMPLATE_TEST_CASE("WeakLearnerErrorNonLinearSepData_DS", "[AdaBoostTest]", mat,
  * dataset.  It tests the Classify function and checks for a satisfactory error
  * rate.
  */
-TEMPLATE_TEST_CASE("ClassifyTest_VERTEBRALCOL", "[AdaBoostTest]", mat, fmat)
+TEMPLATE_TEST_CASE("ClassifyTest_VERTEBRALCOL", "[AdaBoostTest][long]", mat,
+    fmat)
 {
   using MatType = TestType;
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("vc2.csv", inputData))
+  if (!Load("vc2.csv", inputData))
     FAIL("Cannot load test dataset vc2.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("vc2_labels.txt", labels))
+  if (!Load("vc2_labels.txt", labels))
     FAIL("Cannot load labels for vc2_labels.txt");
 
   // Define your own weak learner, perceptron in this case.
@@ -603,12 +604,12 @@ TEMPLATE_TEST_CASE("ClassifyTest_VERTEBRALCOL", "[AdaBoostTest]", mat, fmat)
   size_t perceptronIter = 1000;
 
   MatType testData;
-  if (!data::Load("vc2_test.csv", testData))
+  if (!Load("vc2_test.csv", testData))
     FAIL("Cannot load test dataset vc2_test.csv!");
 
   Mat<size_t> trueTestLabels;
 
-  if (!data::Load("vc2_test_labels.txt", trueTestLabels))
+  if (!Load("vc2_test_labels.txt", trueTestLabels))
     FAIL("Cannot load labels for vc2_test_labels.txt");
 
   const size_t numClasses = max(labels.row(0)) + 1;
@@ -665,11 +666,11 @@ TEMPLATE_TEST_CASE("ClassifyTest_NONLINSEP", "[AdaBoostTest]", mat, fmat)
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("train_nonlinsep.txt", inputData))
+  if (!Load("train_nonlinsep.txt", inputData))
     FAIL("Cannot load test dataset train_nonlinsep.txt!");
 
   Mat<size_t> labels;
-  if (!data::Load("train_labels_nonlinsep.txt", labels))
+  if (!Load("train_labels_nonlinsep.txt", labels))
     FAIL("Cannot load labels for train_labels_nonlinsep.txt");
 
   // Define your own weak learner; in this test decision stumps are used.
@@ -679,11 +680,11 @@ TEMPLATE_TEST_CASE("ClassifyTest_NONLINSEP", "[AdaBoostTest]", mat, fmat)
 
   MatType testData;
 
-  if (!data::Load("test_nonlinsep.txt", testData))
+  if (!Load("test_nonlinsep.txt", testData))
     FAIL("Cannot load test dataset test_nonlinsep.txt!");
 
   Mat<size_t> trueTestLabels;
-  if (!data::Load("test_labels_nonlinsep.txt", trueTestLabels))
+  if (!Load("test_labels_nonlinsep.txt", trueTestLabels))
     FAIL("Cannot load labels for test_labels_nonlinsep.txt");
 
   Row<size_t> dsPrediction(labels.n_cols);
@@ -736,11 +737,11 @@ TEMPLATE_TEST_CASE("ClassifyTest_IRIS", "[AdaBoostTest]", mat, fmat)
   using eT = typename MatType::elem_type;
 
   MatType inputData;
-  if (!data::Load("iris_train.csv", inputData))
+  if (!Load("iris_train.csv", inputData))
     FAIL("Cannot load test dataset iris_train.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("iris_train_labels.csv", labels))
+  if (!Load("iris_train_labels.csv", labels))
     FAIL("Cannot load labels for iris_train_labels.csv");
   const size_t numClasses = max(labels.row(0)) + 1;
 
@@ -759,14 +760,14 @@ TEMPLATE_TEST_CASE("ClassifyTest_IRIS", "[AdaBoostTest]", mat, fmat)
       iterations, tolerance, perceptronIter);
 
   MatType testData;
-  if (!data::Load("iris_test.csv", testData))
+  if (!Load("iris_test.csv", testData))
     FAIL("Cannot load test dataset iris_test.csv!");
 
   Row<size_t> predictedLabels(testData.n_cols);
   a.Classify(testData, predictedLabels);
 
   Mat<size_t> trueTestLabels;
-  if (!data::Load("iris_test_labels.csv", trueTestLabels))
+  if (!Load("iris_test_labels.csv", trueTestLabels))
     FAIL("Cannot load test dataset iris_test_labels.csv!");
 
   Row<size_t> predictedLabels1(testData.n_cols),
@@ -808,11 +809,11 @@ TEMPLATE_TEST_CASE("TrainTest", "[AdaBoostTest]", mat, fmat)
 
   // First train on the iris dataset.
   MatType inputData;
-  if (!data::Load("iris_train.csv", inputData))
+  if (!Load("iris_train.csv", inputData))
     FAIL("Cannot load test dataset iris_train.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("iris_train_labels.csv", labels))
+  if (!Load("iris_train_labels.csv", labels))
     FAIL("Cannot load labels for iris_train_labels.csv");
 
   const size_t numClasses = max(labels.row(0)) + 1;
@@ -829,9 +830,9 @@ TEMPLATE_TEST_CASE("TrainTest", "[AdaBoostTest]", mat, fmat)
       iterations, tolerance, perceptronIter);
 
   // Now load another dataset...
-  if (!data::Load("vc2.csv", inputData))
+  if (!Load("vc2.csv", inputData))
     FAIL("Cannot load test dataset vc2.csv!");
-  if (!data::Load("vc2_labels.txt", labels))
+  if (!Load("vc2_labels.txt", labels))
     FAIL("Cannot load labels for vc2_labels.txt");
 
   const size_t newNumClasses = max(labels.row(0)) + 1;
@@ -843,11 +844,11 @@ TEMPLATE_TEST_CASE("TrainTest", "[AdaBoostTest]", mat, fmat)
 
   // Load test set to see if it trained on vc2 correctly.
   MatType testData;
-  if (!data::Load("vc2_test.csv", testData))
+  if (!Load("vc2_test.csv", testData))
     FAIL("Cannot load test dataset vc2_test.csv!");
 
   Mat<size_t> trueTestLabels;
-  if (!data::Load("vc2_test_labels.txt", trueTestLabels))
+  if (!Load("vc2_test_labels.txt", trueTestLabels))
     FAIL("Cannot load labels for vc2_test_labels.txt");
 
   // Define parameters for AdaBoost.
@@ -860,7 +861,8 @@ TEMPLATE_TEST_CASE("TrainTest", "[AdaBoostTest]", mat, fmat)
   REQUIRE(lError <= 0.30);
 }
 
-TEMPLATE_TEST_CASE("PerceptronSerializationTest", "[AdaBoostTest]", fmat, mat)
+TEMPLATE_TEST_CASE("PerceptronSerializationTest", "[AdaBoostTest][long]", fmat,
+    mat)
 {
   using MatType = TestType;
 
@@ -968,7 +970,8 @@ TEMPLATE_TEST_CASE("ID3DecisionStumpSerializationTest", "[AdaBoostTest]", mat,
   }
 }
 
-TEMPLATE_TEST_CASE("AdaBoostSinglePointClassify", "[AdaBoostTest]", mat, fmat)
+TEMPLATE_TEST_CASE("AdaBoostSinglePointClassify", "[AdaBoostTest][long]", mat,
+    fmat)
 {
   using MatType = TestType;
 
@@ -991,8 +994,8 @@ TEMPLATE_TEST_CASE("AdaBoostSinglePointClassify", "[AdaBoostTest]", mat, fmat)
   }
 }
 
-TEMPLATE_TEST_CASE("AdaBoostSinglePointClassifyWithProbs", "[AdaBoostTest]",
-    mat, fmat)
+TEMPLATE_TEST_CASE("AdaBoostSinglePointClassifyWithProbs",
+    "[AdaBoostTest][long]", mat, fmat)
 {
   using MatType = TestType;
   using eT = typename MatType::elem_type;
@@ -1026,11 +1029,11 @@ TEMPLATE_TEST_CASE("AdaBoostParamsConstructor", "[AdaBoostTest]", fmat, mat)
   using MatType = TestType;
 
   MatType inputData;
-  if (!data::Load("iris.csv", inputData))
+  if (!Load("iris.csv", inputData))
     FAIL("Cannot load test dataset iris.csv!");
 
   Mat<size_t> labels;
-  if (!data::Load("iris_labels.txt", labels))
+  if (!Load("iris_labels.txt", labels))
     FAIL("Cannot load labels for iris iris_labels.txt");
 
   const size_t numClasses = max(labels.row(0)) + 1;
@@ -1059,7 +1062,7 @@ TEMPLATE_TEST_CASE("AdaBoostParamsConstructor", "[AdaBoostTest]", fmat, mat)
 }
 
 // Ensure that all Train() overloads work correctly.
-TEMPLATE_TEST_CASE("AdaBoostTrainOverloads", "[AdaBoostTest]", fmat, mat)
+TEMPLATE_TEST_CASE("AdaBoostTrainOverloads", "[AdaBoostTest][long]", fmat, mat)
 {
   using MatType = TestType;
 
