@@ -28,10 +28,14 @@
 #include "layer/convolution.cpp"
 #include "layer/concat.cpp"
 #include "layer/concatenate.cpp"
+#include "layer/celu.cpp"
 #include "layer/c_relu.cpp"
 #include "layer/dropout.cpp"
+#include "layer/elu.cpp"
+#include "layer/embedding.cpp"
 #include "layer/flexible_relu.cpp"
 #include "layer/grouped_convolution.cpp"
+#include "layer/gru.cpp"
 #include "layer/hard_tanh.cpp"
 #include "layer/identity.cpp"
 #include "layer/linear3d.cpp"
@@ -51,3 +55,4 @@
 #include "layer/ftswish.cpp"
 #include "layer/layer_norm.cpp"
 #include "layer/multihead_attention.cpp"
+#include "layer/sum_reduce.cpp"
