@@ -31,7 +31,7 @@ TEST_CASE("CheckCopyMovingReparametrizationNetworkTest",
 {
   // Load the dataset.
   arma::mat trainData;
-  data::Load("thyroid_train.csv", trainData, true);
+  Load("thyroid_train.csv", trainData, true);
 
   arma::mat trainLabels = trainData.row(trainData.n_rows - 1);
   trainData.shed_row(trainData.n_rows - 1);
@@ -64,7 +64,7 @@ TEST_CASE("CheckCopyMovingReparametrizationNetworkTest",
 // {
 //   // Load the dataset.
 //   arma::mat trainData;
-//   data::Load("thyroid_train.csv", trainData, true);
+//   Load("thyroid_train.csv", trainData, true);
 //
 //   // Normalize labels to [0, 2].
 //   arma::mat trainLabels = trainData.row(trainData.n_rows - 1) - 1;
@@ -100,7 +100,7 @@ TEST_CASE("CheckCopyMovingReparametrizationNetworkTest",
 // {
 //   // Load the dataset.
 //   arma::mat trainData;
-//   data::Load("thyroid_train.csv", trainData, true);
+//   Load("thyroid_train.csv", trainData, true);
 //
 //   // Normalize labels to [0, 2].
 //   arma::mat trainLabels = trainData.row(trainData.n_rows - 1) - 1;
@@ -161,7 +161,7 @@ TEST_CASE("HighwayNetworkTest", "[FeedForwardNetworkTest]")
 // {
 //   // Load the dataset.
 //   arma::mat trainData;
-//   if (!data::Load("thyroid_train.csv", trainData))
+//   if (!Load("thyroid_train.csv", trainData))
 //     FAIL("Cannot open thyroid_train.csv");
 //
 //   arma::mat trainLabels = trainData.row(trainData.n_rows - 1);
@@ -169,7 +169,7 @@ TEST_CASE("HighwayNetworkTest", "[FeedForwardNetworkTest]")
 //   trainLabels -= 1; // The labels should be between 0 and numClasses - 1.
 //
 //   arma::mat testData;
-//   if (!data::Load("thyroid_test.csv", testData))
+//   if (!Load("thyroid_test.csv", testData))
 //     FAIL("Cannot load dataset thyroid_test.csv");
 //
 //   arma::mat testLabels = testData.row(testData.n_rows - 1);
@@ -214,7 +214,7 @@ TEST_CASE("HighwayNetworkTest", "[FeedForwardNetworkTest]")
 // {
 //   // Load the dataset.
 //   arma::mat trainData;
-//   if (!data::Load("thyroid_train.csv", trainData))
+//   if (!Load("thyroid_train.csv", trainData))
 //     FAIL("Cannot open thyroid_train.csv");
 //
 //   arma::mat trainLabels = trainData.row(trainData.n_rows - 1);
@@ -222,7 +222,7 @@ TEST_CASE("HighwayNetworkTest", "[FeedForwardNetworkTest]")
 //   trainLabels -= 1; // The labels should be between 0 and numClasses - 1.
 //
 //   arma::mat testData;
-//   if (!data::Load("thyroid_test.csv", testData))
+//   if (!Load("thyroid_test.csv", testData))
 //     FAIL("Cannot load dataset thyroid_test.csv");
 //
 //   arma::mat testLabels = testData.row(testData.n_rows - 1);
