@@ -24,7 +24,7 @@ using namespace std;
 // Get train and test datasets.
 static void GetDatasets(arma::mat& dataset, arma::mat& savedCols)
 {
-  if (!data::Load("GroupLensSmall.csv", dataset))
+  if (!Load("GroupLensSmall.csv", dataset))
     FAIL("Cannot load test dataset GroupLensSmall.csv!");
   savedCols.set_size(3, 50);
 
@@ -80,7 +80,7 @@ void GetRecommendationsAllUsers()
 
   // Load GroupLens data.
   arma::mat dataset;
-  if (!data::Load("GroupLensSmall.csv", dataset))
+  if (!Load("GroupLensSmall.csv", dataset))
     FAIL("Cannot load test dataset GroupLensSamll.csv!");
 
   CFType<DecompositionPolicy> c(dataset, decomposition, 5, 5, 30);
@@ -118,7 +118,7 @@ void GetRecommendationsQueriedUser()
 
   // Load GroupLens data.
   arma::mat dataset;
-  if (!data::Load("GroupLensSmall.csv", dataset))
+  if (!Load("GroupLensSmall.csv", dataset))
     FAIL("Cannot load test dataset GroupLensSmall.csv!");
 
   CFType<DecompositionPolicy> c(dataset, decomposition, 5, 5, 30);
@@ -419,7 +419,7 @@ void Serialization()
   DecompositionPolicy decomposition;
   // Load a dataset to train on.
   arma::mat dataset;
-  if (!data::Load("GroupLensSmall.csv", dataset))
+  if (!Load("GroupLensSmall.csv", dataset))
     FAIL("Cannot load test dataset GroupLensSmall.csv!");
 
   arma::sp_mat cleanedData;
@@ -498,10 +498,18 @@ void Serialization()
  * Make sure that correct number of recommendations are generated when query
  * set for all methods.
  */
-TEMPLATE_TEST_CASE("CFGetRecommendationsAllUsersTest", "[CFTest]",
+TEMPLATE_TEST_CASE("CFGetRecommendationsAllUsersTest", "[CFTest][tiny]",
     RandomizedSVDPolicy, RegSVDPolicy, BatchSVDPolicy, NMFPolicy,
-    SVDCompletePolicy, SVDIncompletePolicy, BiasSVDPolicy, SVDPlusPlusPolicy,
-    QUIC_SVDPolicy, BlockKrylovSVDPolicy)
+    SVDCompletePolicy, SVDIncompletePolicy, BiasSVDPolicy,
+    BlockKrylovSVDPolicy)
+{
+  GetRecommendationsAllUsers<TestType>();
+}
+
+// The SVDPlusPlus policy takes noticeably longer and the QUIC_SVDPolicy
+// requires a lot of RAM.
+TEMPLATE_TEST_CASE("CFGetRecommendationsAllUsersTest", "[CFTest][long]",
+    QUIC_SVDPolicy, SVDPlusPlusPolicy)
 {
   GetRecommendationsAllUsers<TestType>();
 }
@@ -511,9 +519,16 @@ TEMPLATE_TEST_CASE("CFGetRecommendationsAllUsersTest", "[CFTest]",
  * for all methods.
  */
 TEMPLATE_TEST_CASE("CFGetRecommendationsQueriedUsersTest", "[CFTest]",
-  RandomizedSVDPolicy, RegSVDPolicy, BatchSVDPolicy, NMFPolicy,
-  SVDCompletePolicy, SVDIncompletePolicy, BiasSVDPolicy, SVDPlusPlusPolicy,
-  QUIC_SVDPolicy, BlockKrylovSVDPolicy)
+    RandomizedSVDPolicy, RegSVDPolicy, BatchSVDPolicy, NMFPolicy,
+    SVDCompletePolicy, SVDIncompletePolicy, BiasSVDPolicy, QUIC_SVDPolicy,
+    BlockKrylovSVDPolicy)
+{
+  GetRecommendationsQueriedUser<TestType>();
+}
+
+// The SVDPlusPlus policy takes noticeably longer.
+TEMPLATE_TEST_CASE("CFGetRecommendationsQueriedUsersTest", "[CFTest][long]",
+  SVDPlusPlusPolicy)
 {
   GetRecommendationsQueriedUser<TestType>();
 }
@@ -546,8 +561,15 @@ TEMPLATE_TEST_CASE("RecommendationAccuracyTest", "[CFTest]",
  */
 TEMPLATE_TEST_CASE("CFPredictTest", "[CFTest]",
     RandomizedSVDPolicy, RegSVDPolicy, BatchSVDPolicy, NMFPolicy,
-    SVDCompletePolicy, SVDIncompletePolicy, BiasSVDPolicy, SVDPlusPlusPolicy,
-    QUIC_SVDPolicy, BlockKrylovSVDPolicy)
+    SVDCompletePolicy, SVDIncompletePolicy, BiasSVDPolicy, QUIC_SVDPolicy,
+    BlockKrylovSVDPolicy)
+{
+  CFPredict<TestType>();
+}
+
+// The SVDPlusPlus policy takes noticeably longer.
+TEMPLATE_TEST_CASE("CFPredictTest", "[CFTest][long]",
+    SVDPlusPlusPolicy)
 {
   CFPredict<TestType>();
 }
@@ -557,8 +579,15 @@ TEMPLATE_TEST_CASE("CFPredictTest", "[CFTest]",
  */
 TEMPLATE_TEST_CASE("CFBatchPredictTest", "[CFTest]",
     RandomizedSVDPolicy, RegSVDPolicy, BatchSVDPolicy, NMFPolicy,
-    SVDCompletePolicy, SVDIncompletePolicy, BiasSVDPolicy, SVDPlusPlusPolicy,
-    QUIC_SVDPolicy, BlockKrylovSVDPolicy)
+    SVDCompletePolicy, SVDIncompletePolicy, BiasSVDPolicy, QUIC_SVDPolicy,
+    BlockKrylovSVDPolicy)
+{
+  BatchPredict<TestType>();
+}
+
+// The SVDPlusPlus policy takes noticeably longer.
+TEMPLATE_TEST_CASE("CFBatchPredictTest", "[CFTest][long]",
+    SVDPlusPlusPolicy)
 {
   BatchPredict<TestType>();
 }
@@ -580,7 +609,15 @@ TEMPLATE_TEST_CASE("TrainTest_1", "[CFTest]",
  * some methods
  */
 TEMPLATE_TEST_CASE("TrainTest_2", "[CFTest]",
-    RegSVDPolicy, BiasSVDPolicy, SVDPlusPlusPolicy)
+    RegSVDPolicy, BiasSVDPolicy)
+{
+  TestType decomposition;
+  TrainWithCoordinateList(decomposition);
+}
+
+// The SVDPlusPlus policy takes noticeably longer.
+TEMPLATE_TEST_CASE("TrainTest_2", "[CFTest][long]",
+    SVDPlusPlusPolicy)
 {
   TestType decomposition;
   TrainWithCoordinateList(decomposition);
