@@ -10,17 +10,12 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
-#include <mlpack/core/kernels/gaussian_kernel.hpp>
-#include <mlpack/methods/kernel_pca/kernel_rules/nystroem_method.hpp>
-#include <mlpack/methods/kernel_pca/kernel_pca.hpp>
+#include <mlpack/methods/kernel_pca.hpp>
 
 #include "catch.hpp"
 #include "test_catch_tools.hpp"
 
 using namespace mlpack;
-using namespace mlpack::math;
-using namespace mlpack::kpca;
-using namespace mlpack::kernel;
 using namespace std;
 using namespace arma;
 
@@ -90,7 +85,7 @@ TEST_CASE("CircleTransformationTestNaive", "[KernelPCATest]")
  * If KernelPCA is working right, then it should turn a circle dataset into a
  * linearly separable dataset in one dimension (which is easy to check).
  */
-TEST_CASE("CircleTransformationTestNystroem", "[KernelPCATest]")
+TEST_CASE("CircleTransformationTestNystroem", "[KernelPCATest][tiny]")
 {
   // The dataset, which will have three concentric rings in three dimensions.
   arma::mat dataset;
