@@ -31,11 +31,11 @@ TEST_CASE_METHOD(DETTestFixture, "DETOutputDimensionTest",
                 "[DETMainTest][BindingTests]")
 {
   arma::mat trainingData;
-  if (!data::Load("iris.csv", trainingData))
+  if (!Load("iris.csv", trainingData))
     FAIL("Unable to load dataset iris.csv!");
 
   arma::mat testData;
-  if (!data::Load("iris_test.csv", testData))
+  if (!Load("iris_test.csv", testData))
     FAIL("Unable to load dataset iris_test.csv!");
 
   // Input data.
@@ -63,7 +63,7 @@ TEST_CASE_METHOD(DETTestFixture, "DETParamBoundTest",
                 "[DETMainTest][BindingTests]")
 {
   arma::mat trainingData;
-  if (!data::Load("iris.csv", trainingData))
+  if (!Load("iris.csv", trainingData))
     FAIL("Unable to load dataset iris.csv!");
 
   // Test for max_leaf_size.
@@ -99,11 +99,11 @@ TEST_CASE_METHOD(DETTestFixture, "DETModelReuseTest",
                 "[DETMainTest][BindingTests]")
 {
   arma::mat trainingData;
-  if (!data::Load("iris.csv", trainingData))
+  if (!Load("iris.csv", trainingData))
     FAIL("Unable to load dataset iris.csv!");
 
   arma::mat testData;
-  if (!data::Load("iris_test.csv", testData))
+  if (!Load("iris_test.csv", testData))
     FAIL("Unable to load dataset iris_test.csv!");
 
   // Input data.
@@ -138,11 +138,11 @@ TEST_CASE_METHOD(DETTestFixture, "DETViDimensionTest",
                 "[DETMainTest][BindingTests]")
 {
   arma::mat trainingData;
-  if (!data::Load("iris.csv", trainingData))
+  if (!Load("iris.csv", trainingData))
     FAIL("Unable to load dataset iris.csv!");
 
   arma::mat testData;
-  if (!data::Load("iris_test.csv", testData))
+  if (!Load("iris_test.csv", testData))
     FAIL("Unable to load dataset iris_test.csv!");
 
   size_t testRows = testData.n_rows;
@@ -165,7 +165,7 @@ TEST_CASE_METHOD(DETTestFixture, "DETModelValidityTest",
                 "[DETMainTest][BindingTests]")
 {
   arma::mat trainingData;
-  if (!data::Load("iris.csv", trainingData))
+  if (!Load("iris.csv", trainingData))
     FAIL("Unable to load dataset iris.csv!");
 
   SetInputParam("training", std::move(trainingData));
@@ -187,11 +187,11 @@ TEST_CASE_METHOD(DETTestFixture, "DETDiffMinLeafTest",
                 "[DETMainTest][BindingTests]")
 {
   arma::mat trainingData;
-  if (!data::Load("iris.csv", trainingData))
+  if (!Load("iris.csv", trainingData))
     FAIL("Unable to load dataset iris.csv!");
 
   arma::mat testData;
-  if (!data::Load("iris_test.csv", testData))
+  if (!Load("iris_test.csv", testData))
     FAIL("Unable to load dataset iris_test.csv!");
 
   // Input data.
@@ -232,11 +232,11 @@ TEST_CASE_METHOD(DETTestFixture, "DETDiffMaxLeafTest",
                 "[DETMainTest][BindingTests]")
 {
   arma::mat trainingData;
-  if (!data::Load("iris.csv", trainingData))
+  if (!Load("iris.csv", trainingData))
     FAIL("Unable to load dataset iris.csv!");
 
   arma::mat testData;
-  if (!data::Load("iris_test.csv", testData))
+  if (!Load("iris_test.csv", testData))
     FAIL("Unable to load dataset iris_test.csv!");
 
   // Input data.
@@ -277,11 +277,11 @@ TEST_CASE_METHOD(DETTestFixture, "DETDiffFoldsTest",
                 "[DETMainTest][BindingTests]")
 {
   arma::mat trainingData;
-  if (!data::Load("iris.csv", trainingData))
+  if (!Load("iris.csv", trainingData))
     FAIL("Unable to load dataset iris.csv!");
 
   arma::mat testData;
-  if (!data::Load("iris_test.csv", testData))
+  if (!Load("iris_test.csv", testData))
     FAIL("Unable to load dataset iris_test.csv!");
 
   // Input data.
@@ -322,11 +322,11 @@ TEST_CASE_METHOD(DETTestFixture, "DETSkipPruningTest",
                 "[DETMainTest][BindingTests]")
 {
   arma::mat trainingData;
-  if (!data::Load("iris.csv", trainingData))
+  if (!Load("iris.csv", trainingData))
     FAIL("Unable to load dataset iris.csv!");
 
   arma::mat testData;
-  if (!data::Load("iris_test.csv", testData))
+  if (!Load("iris_test.csv", testData))
     FAIL("Unable to load dataset iris_test.csv!");
 
   // Input data.
