@@ -33,7 +33,7 @@ TEST_CASE_METHOD(HMMLoglikTestFixture, "HMMLoglikOutputNegativeTest",
 {
   // Load data to train a discrete HMM model with.
   arma::mat inp;
-  data::Load("obs1.csv", inp);
+  Load("obs1.csv", inp);
   std::vector<arma::mat> trainSeq = {inp};
 
   // Initialize and train an HMM model.
