@@ -32,9 +32,12 @@ TEST_CASE_METHOD(
     PreprocessImputerTestFixture, "PreprocessImputerDimensionTest",
     "[PreprocessImputerMainTest][BindingTests]")
 {
-  // Load synthetic dataset.
+  // Load synthetic dataset.  NaNs will load as 0.
   arma::mat inputData;
-  data::Load("preprocess_imputer_test.csv", inputData);
+  // TODO: when DataOptions refactoring is done, this should load so that
+  // invalid tokens map to NaN, and the replace() can be removed.
+  Load("preprocess_imputer_test.csv", inputData);
+  inputData.replace(0.0, std::nan(""));
 
   arma::mat outputData;
 
@@ -42,18 +45,13 @@ TEST_CASE_METHOD(
   size_t inputSize = inputData.n_cols;
 
   // Input custom data points and labels.
-  SetInputParam("input_file", (std::string) "preprocess_imputer_test.csv");
-  SetInputParam("missing_value", (std::string) "nan");
-  SetInputParam("output_file",
-      (std::string) "preprocess_imputer_output_test.csv");
-
-  // Check for mean strategy.
+  SetInputParam("input", inputData);
   SetInputParam("strategy", (std::string) "mean");
 
   RUN_BINDING();
 
   // Now check that the output has desired dimensions.
-  data::Load(params.Get<std::string>("output_file"), outputData);
+  outputData = std::move(params.Get<arma::mat>("output"));
   REQUIRE(outputData.n_cols == inputSize);
   REQUIRE(outputData.n_rows == 3); // Input Dimension.
 
@@ -61,16 +59,13 @@ TEST_CASE_METHOD(
   ResetSettings();
 
   // Check for median strategy.
-  SetInputParam("input_file", (std::string) "preprocess_imputer_test.csv");
-  SetInputParam("missing_value", (std::string) "nan");
-  SetInputParam("output_file",
-      (std::string) "preprocess_imputer_output_test.csv");
+  SetInputParam("input", inputData);
   SetInputParam("strategy", (std::string) "median");
 
   RUN_BINDING();
 
   // Now check that the output has desired dimensions.
-  data::Load(params.Get<std::string>("output_file"), outputData);
+  outputData = std::move(params.Get<arma::mat>("output"));
   REQUIRE(outputData.n_cols == inputSize);
   REQUIRE(outputData.n_rows == 3); // Input Dimension.
 
@@ -78,17 +73,14 @@ TEST_CASE_METHOD(
   ResetSettings();
 
   // Check for custom strategy.
-  SetInputParam("input_file", (std::string) "preprocess_imputer_test.csv");
-  SetInputParam("missing_value", (std::string) "nan");
-  SetInputParam("output_file",
-      (std::string) "preprocess_imputer_output_test.csv");
+  SetInputParam("input", inputData);
   SetInputParam("strategy", (std::string) "custom");
   SetInputParam("custom_value", (double) 75.12);
 
   RUN_BINDING();
 
   // Now check that the output has desired dimensions.
-  data::Load(params.Get<std::string>("output_file"), outputData);
+  outputData = std::move(params.Get<arma::mat>("output"));
   REQUIRE(outputData.n_cols == inputSize);
   REQUIRE(outputData.n_rows == 3); // Input Dimension.
 }
@@ -102,35 +94,33 @@ TEST_CASE_METHOD(
 {
   // Load synthetic dataset.
   arma::mat inputData;
-  data::Load("preprocess_imputer_test.csv", inputData);
+  // TODO: when DataOptions refactoring is done, this should load so that
+  // invalid tokens map to NaN, and the replace() can be removed.
+  Load("preprocess_imputer_test.csv", inputData);
+  inputData.replace(0.0, std::nan(""));
 
   // Store size of input dataset.
-  size_t inputSize  = inputData.n_cols;
+  size_t inputSize = inputData.n_cols;
   size_t countNaN = 0;
 
   // Count number of unavailable entries in all dimensions.
   for (size_t i = 0; i < inputSize; ++i)
   {
-    if (std::to_string(inputData(0, i)) == "nan" ||
-        std::to_string(inputData(1, i)) == "nan" ||
-        std::to_string(inputData(2, i)) == "nan")
+    if (std::isnan(inputData(0, i)) || std::isnan(inputData(1, i)) ||
+        std::isnan(inputData(2, i)))
     {
       countNaN++;
     }
   }
 
   // Input custom data points and labels.
-  SetInputParam("input_file", (std::string) "preprocess_imputer_test.csv");
-  SetInputParam("missing_value", (std::string) "nan");
+  SetInputParam("input", inputData);
   SetInputParam("strategy", (std::string) "listwise_deletion");
-  SetInputParam("output_file",
-      (std::string) "preprocess_imputer_output_test.csv");
 
   RUN_BINDING();
 
   // Now check that the output has desired dimensions.
-  arma::mat outputData;
-  data::Load(params.Get<std::string>("output_file"), outputData);
+  arma::mat outputData = std::move(params.Get<arma::mat>("output"));
   REQUIRE(outputData.n_cols + countNaN == inputSize);
   REQUIRE(outputData.n_rows == 3); // Input Dimension.
 }
@@ -144,12 +134,76 @@ TEST_CASE_METHOD(
 {
   // Load synthetic dataset.
   arma::mat inputData;
-  data::Load("preprocess_imputer_test.csv", inputData);
+  // TODO: when DataOptions refactoring is done, this should load so that
+  // invalid tokens map to NaN, and the replace() can be removed.
+  Load("preprocess_imputer_test.csv", inputData);
+  inputData.replace(0.0, std::nan(""));
 
   // Input custom data points and labels.
-  SetInputParam("input_file", (std::string) "preprocess_imputer_test.csv");
-  SetInputParam("missing_value", (std::string) "nan");
+  SetInputParam("input", inputData);
   SetInputParam("strategy", (std::string) "notmean"); // Invalid.
 
   REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
+
+/**
+ * Check that a custom missing value can be specified.
+ */
+TEST_CASE_METHOD(
+    PreprocessImputerTestFixture, "PreprocessImputerCustomMissingValueTest",
+    "[PreprocessImputerMainTest][BindingTests]")
+{
+  // Load synthetic dataset.
+  arma::mat inputData;
+  // TODO: when DataOptions refactoring is done, this should load so that
+  // invalid tokens map to 0.0.
+  Load("preprocess_imputer_test.csv", inputData);
+  inputData.replace(std::nan(""), 0.0);
+
+  // Input custom data points and labels.
+  SetInputParam("input", inputData);
+  SetInputParam("missing_value", 0.0);
+  SetInputParam("strategy", (std::string) "mean");
+
+  RUN_BINDING();
+
+  arma::mat outputData = std::move(params.Get<arma::mat>("output"));
+
+  // There shouldn't be any more 0s in the matrix.
+  arma::uvec r = find(outputData == 0.0);
+  REQUIRE(r.n_elem == 0);
+}
+
+/**
+ * Check that a single dimension can be specified.
+ */
+TEST_CASE_METHOD(
+    PreprocessImputerTestFixture, "PreprocessImputerSingleDimensionTest",
+    "[PreprocessImputerMainTest][BindingTests]")
+{
+  // Load synthetic dataset.
+  arma::mat inputData;
+  // TODO: when DataOptions refactoring is done, this should load so that
+  // invalid tokens map to NaN.  (Or the test case should be adapted.)
+  Load("preprocess_imputer_test.csv", inputData);
+  inputData.replace(std::nan(""), 0.0);
+
+  // Input custom data points and labels.
+  SetInputParam("input", inputData);
+  SetInputParam("missing_value", 0.0);
+  SetInputParam("dimension", 0);
+  SetInputParam("strategy", (std::string) "mean");
+
+  RUN_BINDING();
+
+  arma::mat outputData = std::move(params.Get<arma::mat>("output"));
+
+  // There shouldn't be any more 0s in row 0.
+  arma::uvec r = find(outputData.row(0) == 0.0);
+  REQUIRE(r.n_elem == 0);
+  // But there should still be some in other rows.
+  r = find(outputData.row(1) == 0.0);
+  REQUIRE(r.n_elem > 0);
+  r = find(outputData.row(2) == 0.0);
+  REQUIRE(r.n_elem > 0);
+}
