@@ -56,9 +56,10 @@ MatType GetMeanShiftData()
 /**
  * 30-point 3-class test case for Mean Shift.
  */
-TEMPLATE_TEST_CASE("MeanShiftSimpleTest", "[MeanShiftTest]", float, double)
+TEMPLATE_TEST_CASE("MeanShiftSimpleTest", "[MeanShiftTest][tiny]", float,
+    double)
 {
-  typedef TestType ElemType;
+  using ElemType = TestType;
 
   MeanShift<> meanShift;
 
@@ -95,7 +96,7 @@ TEMPLATE_TEST_CASE("MeanShiftSimpleTest", "[MeanShiftTest]", float, double)
 TEMPLATE_TEST_CASE("MeanShiftSimpleCentroidsOnlyTest", "[MeanShiftTest]", float,
     double)
 {
-  typedef TestType ElemType;
+  using ElemType = TestType;
 
   MeanShift<> meanShift;
 
@@ -110,8 +111,8 @@ TEMPLATE_TEST_CASE("MeanShiftSimpleCentroidsOnlyTest", "[MeanShiftTest]", float,
 // recovers those four centers.
 TEMPLATE_TEST_CASE("GaussianClustering", "[MeanShiftTest]", float, double)
 {
-  typedef TestType ElemType;
-  typedef typename arma::Mat<ElemType> MatType;
+  using ElemType = TestType;
+  using MatType = arma::Mat<ElemType>;
 
   GaussianDistribution<MatType> g1("0.0 0.0 0.0", arma::eye<MatType>(3, 3));
   GaussianDistribution<MatType> g2("5.0 5.0 5.0", 2 * arma::eye<MatType>(3, 3));
@@ -163,7 +164,8 @@ TEMPLATE_TEST_CASE("GaussianClustering", "[MeanShiftTest]", float, double)
           centroids.col(i));
 
       // Are we near a centroid of a Gaussian?
-      const ElemType minVal = centroidDistances.min(minIndices[i]);
+      minIndices[i] = centroidDistances.index_min();
+      const ElemType minVal = centroidDistances(minIndices[i]);
       success = (std::abs(minVal) <= 0.65);
       if (!success)
         break;
@@ -188,8 +190,8 @@ TEMPLATE_TEST_CASE("GaussianClustering", "[MeanShiftTest]", float, double)
 TEMPLATE_TEST_CASE("GaussianClusteringCentroidsOnly", "[MeanShiftTest]", float,
     double)
 {
-  typedef TestType ElemType;
-  typedef typename arma::Mat<ElemType> MatType;
+  using ElemType = TestType;
+  using MatType = arma::Mat<ElemType>;
 
   GaussianDistribution<MatType> g1("0.0 0.0 0.0", arma::eye<MatType>(3, 3));
   GaussianDistribution<MatType> g2("5.0 5.0 5.0", 2 * arma::eye<MatType>(3, 3));
@@ -240,7 +242,8 @@ TEMPLATE_TEST_CASE("GaussianClusteringCentroidsOnly", "[MeanShiftTest]", float,
           centroids.col(i));
 
       // Are we near a centroid of a Gaussian?
-      const ElemType minVal = centroidDistances.min(minIndices[i]);
+      minIndices[i] = centroidDistances.index_min();
+      const ElemType minVal = centroidDistances(minIndices[i]);
       success = (std::abs(minVal) <= 0.65);
       if (!success)
         break;
