@@ -16,14 +16,15 @@
 using namespace mlpack;
 using namespace std;
 
-TEMPLATE_TEST_CASE("Radical_Test_Radical3D", "[RadicalTest]", float, double)
+TEMPLATE_TEST_CASE("Radical_Test_Radical3D", "[RadicalTest][tiny]", float,
+    double)
 {
   using ElemType = TestType;
   using VecType = arma::Col<ElemType>;
   using MatType = arma::Mat<ElemType>;
 
   MatType matX;
-  if (!data::Load("data_3d_mixed.txt", matX))
+  if (!Load("data_3d_mixed.txt", matX))
     FAIL("Cannot load dataset data_3d_mixed.txt");
 
   Radical rad(0.175, 5, 100, matX.n_rows - 1);
@@ -44,7 +45,7 @@ TEMPLATE_TEST_CASE("Radical_Test_Radical3D", "[RadicalTest]", float, double)
   }
 
   MatType matS;
-  if (!data::Load("data_3d_ind.txt", matS))
+  if (!Load("data_3d_ind.txt", matS))
     FAIL("Cannot load dataset data_3d_ind.txt");
   rad.Apply(matS, matY, matW);
 
