@@ -23,7 +23,7 @@ using namespace arma;
  * Test for convergence of incomplete incremenal learning.
  */
 TEMPLATE_TEST_CASE("SVDIncompleteIncrementalConvergenceTest",
-    "[SVDIncrementalTest]", float, double)
+    "[SVDIncrementalTest][tiny]", float, double)
 {
   using eT = TestType;
 
@@ -51,7 +51,7 @@ TEMPLATE_TEST_CASE("SVDIncompleteIncrementalConvergenceTest",
  * Test for convergence of complete incremenal learning
  */
 TEMPLATE_TEST_CASE("SVDCompleteIncrementalConvergenceTest",
-    "[SVDIncrementalTest]", float, double)
+    "[SVDIncrementalTest][tiny]", float, double)
 {
   using eT = TestType;
 
@@ -99,12 +99,12 @@ class SpecificRandomInitialization
 };
 
 TEMPLATE_TEST_CASE("SVDIncompleteIncrementalRegularizationTest",
-    "[SVDIncrementalTest]", float, double)
+    "[SVDIncrementalTest][long]", float, double)
 {
   using eT = TestType;
 
   Mat<eT> dataset;
-  if (!data::Load("GroupLensSmall.csv", dataset))
+  if (!Load("GroupLensSmall.csv", dataset))
     FAIL("Cannot load dataset GroupLensSmall.csv");
 
   // Generate list of locations for batch insert constructor for sparse
