@@ -177,7 +177,7 @@ TEST_CASE("VPTreeBoundTest", "[VantagePointTreeTest]")
   CheckBound(tree);
 }
 
-TEST_CASE("VPTreeTest", "[VantagePointTreeTest]")
+TEST_CASE("VPTreeTest", "[VantagePointTreeTest][long]")
 {
   using TreeType = VPTree<EuclideanDistance, EmptyStatistic, arma::mat>;
 
@@ -231,12 +231,12 @@ TEST_CASE("SingleVPTreeTraverserTest", "[VantagePointTreeTest]")
 
   // Nearest neighbor search with the VP tree.
   NeighborSearch<NearestNeighborSort, LMetric<2, true>, arma::mat, VPTree>
-      knn1(dataset, SINGLE_TREE_MODE);
+      knn1(dataset, SINGLE_TREE);
 
   knn1.Search(5, neighbors1, distances1);
 
   // Nearest neighbor search the naive way.
-  KNN knn2(dataset, NAIVE_MODE);
+  KNN knn2(dataset, NAIVE);
 
   knn2.Search(5, neighbors2, distances2);
 
@@ -258,12 +258,12 @@ TEST_CASE("DualVPTreeTraverserTest", "[VantagePointTreeTest]")
 
   // Nearest neighbor search with the VP tree.
   NeighborSearch<NearestNeighborSort, LMetric<2, true>, arma::mat, VPTree>
-      knn1(dataset, DUAL_TREE_MODE);
+      knn1(dataset, DUAL_TREE);
 
   knn1.Search(5, neighbors1, distances1);
 
   // Nearest neighbor search the naive way.
-  KNN knn2(dataset, NAIVE_MODE);
+  KNN knn2(dataset, NAIVE);
 
   knn2.Search(5, neighbors2, distances2);
 
